@@ -1,6 +1,6 @@
 /*
  * NVIDIA CUDA Debugger CUDA-GDB
- * Copyright (C) 2007-2024 NVIDIA Corporation
+ * Copyright (C) 2007-2025 NVIDIA Corporation
  * Written by CUDA-GDB team at NVIDIA <cudatools@nvidia.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,6 @@
 
 /* Early declarations to avoid cyclic dependencies */
 
-struct kernel_st;
-typedef struct kernel_st *kernel_t;
-
 struct regmap_st;
 typedef struct regmap_st *regmap_t;
 
