@@ -222,9 +222,6 @@ cudbgTraceValue (CUDBGException_t *value)
     {
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_UNKNOWN) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_NONE) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_ILLEGAL_ADDRESS) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_USER_STACK_OVERFLOW) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_DEVICE_HARDWARE_STACK_OVERFLOW)
       break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_ILLEGAL_INSTRUCTION) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_OUT_OF_RANGE_ADDRESS) break;
@@ -234,18 +231,26 @@ cudbgTraceValue (CUDBGException_t *value)
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_HARDWARE_STACK_OVERFLOW)
       break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_DEVICE_ILLEGAL_ADDRESS) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_MISALIGNED_ADDRESS) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_ASSERT) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_SYSCALL_ERROR) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_ILLEGAL_ADDRESS) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_NONMIGRATABLE_ATOMSYS) break;
-      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_LANE_INVALID_ATOMSYS) break;
-#if (CUDBG_API_VERSION_REVISION >= 131)
+      CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_INVALID_MANAGED_MEMORY_ACCESS) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_CLUSTER_BLOCK_NOT_PRESENT) break;
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_CLUSTER_OUT_OF_RANGE_ADDRESS)
       break;
-#endif
       CASE_PRINT_ENUM_VALUE (CUDBG_EXCEPTION_WARP_STACK_CANARY) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_MISALIGNED_PC) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_PC_OVERFLOW) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_MISALIGNED_REG) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_ILLEGAL_INSTR_ENCODING) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_ILLEGAL_INSTR_PARAM) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_OUT_OF_RANGE_REGISTER) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_INVALID_CONST_ADDR_LDC) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_MMU_FAULT) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_ARRIVE) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_CLUSTER_POISON) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_API_STACK_ERROR) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_BLOCK_NOT_PRESENT) break;
+      CASE_PRINT_ENUM_VALUE(CUDBG_EXCEPTION_WARP_USER_STACK_OVERFLOW) break;
       CASE_PRINT_ENUM_DEFAULT (*value) break;
     }
   fflush (s_traceFile);
@@ -498,7 +503,6 @@ cudbgTraceValue (CUDBGMemoryInfo *value)
   PRINT_CUDBG_MEMORY_INFO_FIELD (value, size);
 }
 
-#if CUDBG_API_VERSION_REVISION >= 132
 #define PRINT_CUDBG_LOADED_FUNCTION_INFO_FIELD(pLoadedFunctionInfo, field)    \
   do                                                                          \
     {                                                                         \
@@ -512,7 +516,6 @@ cudbgTraceValue (CUDBGLoadedFunctionInfo *value)
   PRINT_CUDBG_LOADED_FUNCTION_INFO_FIELD (value, sectionIndex);
   PRINT_CUDBG_LOADED_FUNCTION_INFO_FIELD (value, address);
 }
-#endif
 
 static const char *
 cudbgTrimAmpersand (const char *name)
