@@ -672,7 +672,7 @@ nto_procfs::files_info ( )
 {
   struct inferior *inf = current_inferior ();
 
-  printf_unfiltered ("\tUsing the running image of %s %s.\n",
+  gdb_printf ("\tUsing the running image of %s %s.\n",
          inf->attach_flag ? "attached" : "child",
          target_pid_to_str (inferior_ptid).c_str () );
 }
