@@ -108,6 +108,8 @@
  *   - Added per-lane thread state
  * CUDA Driver r580:
  *   - Added CUDA exception string
+ * CUDA Driver r590:
+ *   - Added per-warp barrier scope and additional barrier information
  */
 
 /* ======================================= */
@@ -724,6 +726,17 @@ typedef struct {
     uint32_t cbuExitedLanesMask;
     /* Mask of lanes participating in a collective region */
     uint32_t cbuCollectiveLanesMask;
+
+    /* ================================== */
+    /* ===== Since CUDA Driver r590 ===== */
+    /* ================================== */
+
+    /* This field is of type CUDBGBarrierScope */
+    uint32_t barrierScope;
+    /* Padding, ignore */
+    uint32_t padding3;
+    /* This field is an index into the string table. */
+    uint64_t additionalBarrierInfo;
 } CudbgWarpTableEntry;
 
 /*
