@@ -794,7 +794,7 @@ typedef enum SANITIZER_CBID_DRIVER_API_enum {
    SANITIZER_CBID_DRIVER_API_cuEventElapsedTime_v2                                        = 780,
    SANITIZER_CBID_DRIVER_API_cuTensorMapEncodeIm2colWide                                  = 781,
    SANITIZER_CBID_DRIVER_API_cuGreenCtxGetId                                              = 782,
-   SANITIZER_CBID_DRIVER_API_cuStreamCreateForCaptureToCig                                = 783,
+   SANITIZER_CBID_DRIVER_API_cuStreamBeginCaptureToCig                                    = 783,
    SANITIZER_CBID_DRIVER_API_cuMemPrefetchBatchAsync                                      = 784,
    SANITIZER_CBID_DRIVER_API_cuMemPrefetchBatchAsync_ptsz                                 = 785,
    SANITIZER_CBID_DRIVER_API_cuSemaphoreCreate                                            = 786,
@@ -818,7 +818,23 @@ typedef enum SANITIZER_CBID_DRIVER_API_enum {
    SANITIZER_CBID_DRIVER_API_cuDeviceGetP2PAtomicCapabilities                             = 804,
    SANITIZER_CBID_DRIVER_API_cuDeviceGetHostAtomicCapabilities                            = 805,
    SANITIZER_CBID_DRIVER_API_cuDriverGetGpuCodeIsaVersion                                 = 806,
-   SANITIZER_CBID_DRIVER_API_SIZE                                                         = 807,
+   SANITIZER_CBID_DRIVER_API_cuStreamGetDevResource                                       = 807,
+   SANITIZER_CBID_DRIVER_API_cuStreamGetDevResource_ptsz                                  = 808,
+   SANITIZER_CBID_DRIVER_API_cuGraphNodeGetContainingGraph                                = 809,
+   SANITIZER_CBID_DRIVER_API_cuGraphNodeGetLocalId                                        = 810,
+   SANITIZER_CBID_DRIVER_API_cuGraphNodeGetToolsId                                        = 811,
+   SANITIZER_CBID_DRIVER_API_cuGraphGetId                                                 = 812,
+   SANITIZER_CBID_DRIVER_API_cuGraphExecGetId                                             = 813,
+   SANITIZER_CBID_DRIVER_API_cuStreamBeginCaptureToCig_ptsz                               = 814,
+   SANITIZER_CBID_DRIVER_API_cuStreamEndCaptureToCig                                      = 815,
+   SANITIZER_CBID_DRIVER_API_cuStreamEndCaptureToCig_ptsz                                 = 816,
+   SANITIZER_CBID_DRIVER_API_cuGraphCreateWithArguments                                   = 817,
+   SANITIZER_CBID_DRIVER_API_cuGraphNodeAddRelocation                                     = 818,
+   SANITIZER_CBID_DRIVER_API_cuGraphLaunchWithArguments                                   = 819,
+   SANITIZER_CBID_DRIVER_API_cuMulticastBindMem_v2                                        = 820,
+   SANITIZER_CBID_DRIVER_API_cuMulticastBindAddr_v2                                       = 821,
+   SANITIZER_CBID_DRIVER_API_cuDevSmResourceSplit                                         = 822,
+   SANITIZER_CBID_DRIVER_API_SIZE                                                         = 823,
    SANITIZER_CBID_DRIVER_API_FORCE_INT                                                    = 0x7fffffff,
 } SANITIZER_CBID_DRIVER_API;
 
