@@ -22,10 +22,12 @@
 #define EXIT_WAIVED 2
 #endif
 
-#if defined(WIN32) || defined(_WIN32)
-#define stricmp _stricmp
+#if defined(_WIN32) || defined(_WIN64)
+    #include <cstring>
+    #define stricmp _stricmp
 #else
-#define stricmp strcasecmp
+    #include <strings.h>
+    #define stricmp strcasecmp
 #endif
 
 #define CUDA_MAX_DEVICES    256     // consider theoretical max devices as 256
