@@ -25,7 +25,9 @@
 #include <cuda/__fwd/barrier.h>
 #include <cuda/std/cstdint>
 
-#if _CCCL_HAS_CUDA_COMPILER()
+#if _CCCL_CUDA_COMPILATION()
+
+#  include <cuda/std/__cccl/prologue.h>
 
 _LIBCUDACXX_BEGIN_NAMESPACE_CUDA_DEVICE
 
@@ -36,6 +38,8 @@ _CCCL_DEVICE inline _CUDA_VSTD::uint64_t* barrier_native_handle(barrier<thread_s
 
 _LIBCUDACXX_END_NAMESPACE_CUDA_DEVICE
 
-#endif // _CCCL_HAS_CUDA_COMPILER()
+#  include <cuda/std/__cccl/epilogue.h>
+
+#endif // _CCCL_CUDA_COMPILATION()
 
 #endif // _CUDA___BARRIER_BARRIER_NATIVE_HANDLE_H
