@@ -22,11 +22,13 @@
 
 #include <cuda/std/__utility/convert_to_integral.h>
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 _CCCL_EXEC_CHECK_DISABLE
 template <class _OutputIterator, class _Size, class _Generator>
-_LIBCUDACXX_HIDE_FROM_ABI constexpr _OutputIterator generate_n(_OutputIterator __first, _Size __orig_n, _Generator __gen)
+_CCCL_API constexpr _OutputIterator generate_n(_OutputIterator __first, _Size __orig_n, _Generator __gen)
 {
   using _IntegralSize = decltype(__convert_to_integral(__orig_n));
   _IntegralSize __n   = static_cast<_IntegralSize>(__orig_n);
@@ -39,4 +41,6 @@ _LIBCUDACXX_HIDE_FROM_ABI constexpr _OutputIterator generate_n(_OutputIterator _
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___ALGORITHM_GENERATE_N_H
