@@ -21,13 +21,17 @@
 #  pragma system_header
 #endif // no system header
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 struct __empty_completion
 {
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr void operator()() noexcept {}
+  _CCCL_API constexpr void operator()() noexcept {}
 };
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // __LIBCUDACXX___BARRIER_EMPTY_COMPLETION_H
