@@ -50,6 +50,8 @@
 #include <cuda/std/__utility/in_place.h>
 #include <cuda/std/__utility/move.h>
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 // MSVC complains about [[no_unique_address]] prior to C++20 as a vendor extension
@@ -72,34 +74,34 @@ union __expected_union_t
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Tp2 = _Tp)
   _CCCL_REQUIRES(_CCCL_TRAIT(is_default_constructible, _Tp2))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept(_CCCL_TRAIT(is_nothrow_default_constructible, _Tp2))
+  _CCCL_API constexpr __expected_union_t() noexcept(_CCCL_TRAIT(is_nothrow_default_constructible, _Tp2))
       : __val_()
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Tp2 = _Tp)
   _CCCL_REQUIRES((!_CCCL_TRAIT(is_default_constructible, _Tp2)))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept
+  _CCCL_API constexpr __expected_union_t() noexcept
       : __empty_()
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_union_t(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __val_(_CUDA_VSTD::forward<_Args>(__args)...)
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __unex_(_CUDA_VSTD::forward<_Args>(__args)...)
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+  _CCCL_API constexpr __expected_union_t(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -109,7 +111,7 @@ union __expected_union_t
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+  _CCCL_API constexpr __expected_union_t(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -119,7 +121,7 @@ union __expected_union_t
 
   // the __expected_destruct's destructor handles this
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_union_t() {}
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_union_t() {}
 
   _CCCL_NO_UNIQUE_ADDRESS __empty_t __empty_;
   _CCCL_NO_UNIQUE_ADDRESS _Tp __val_;
@@ -135,33 +137,34 @@ union __expected_union_t<_Tp, _Err, true>
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Tp2 = _Tp)
   _CCCL_REQUIRES(_CCCL_TRAIT(is_default_constructible, _Tp2))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept(_CCCL_TRAIT(is_nothrow_default_constructible, _Tp2))
+  _CCCL_API constexpr __expected_union_t() noexcept(_CCCL_TRAIT(is_nothrow_default_constructible, _Tp2))
       : __val_()
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Tp2 = _Tp)
   _CCCL_REQUIRES((!_CCCL_TRAIT(is_default_constructible, _Tp2)))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept
+  _CCCL_API constexpr __expected_union_t() noexcept
       : __empty_()
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_union_t(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __val_(_CUDA_VSTD::forward<_Args>(__args)...)
   {}
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __unex_(_CUDA_VSTD::forward<_Args>(__args)...)
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+  _CCCL_API constexpr __expected_union_t(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -171,7 +174,7 @@ union __expected_union_t<_Tp, _Err, true>
 
   _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+  _CCCL_API constexpr __expected_union_t(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -198,27 +201,27 @@ struct __expected_destruct<_Tp, _Err, false, false>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept(
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept(
     _CCCL_TRAIT(is_nothrow_default_constructible, _Tp))
       : __has_val_(__has_val)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __union_(in_place, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(true)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -231,7 +234,7 @@ struct __expected_destruct<_Tp, _Err, false, false>
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -244,7 +247,7 @@ struct __expected_destruct<_Tp, _Err, false, false>
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
   {
     if (__has_val_)
     {
@@ -265,27 +268,27 @@ struct __expected_destruct<_Tp, _Err, true, false>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept(
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept(
     _CCCL_TRAIT(is_nothrow_default_constructible, _Tp))
       : __has_val_(__has_val)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __union_(in_place, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(true)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -298,7 +301,7 @@ struct __expected_destruct<_Tp, _Err, true, false>
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -311,7 +314,7 @@ struct __expected_destruct<_Tp, _Err, true, false>
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
   {
     if (!__has_val_)
     {
@@ -328,27 +331,27 @@ struct __expected_destruct<_Tp, _Err, false, true>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept(
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept(
     _CCCL_TRAIT(is_nothrow_default_constructible, _Tp))
       : __has_val_(__has_val)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __union_(in_place, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(true)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -361,7 +364,7 @@ struct __expected_destruct<_Tp, _Err, false, true>
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -374,7 +377,7 @@ struct __expected_destruct<_Tp, _Err, false, true>
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
   {
     if (__has_val_)
     {
@@ -392,27 +395,27 @@ struct __expected_destruct<_Tp, _Err, true, true>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept(
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept(
     _CCCL_TRAIT(is_nothrow_default_constructible, _Tp))
       : __has_val_(__has_val)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(in_place_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Tp, _Args...))
       : __union_(in_place, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(true)
   {}
 
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     in_place_t,
     _Fun&& __fun,
@@ -425,7 +428,7 @@ struct __expected_destruct<_Tp, _Err, true, true>
   {}
 
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -448,31 +451,29 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _T1, class _T2, class... _Args)
   _CCCL_REQUIRES(_CCCL_TRAIT(is_nothrow_constructible, _T1, _Args...))
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void
   __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args) noexcept
   {
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__oldval));
-    _LIBCUDACXX_CONSTRUCT_AT(__newval, _CUDA_VSTD::forward<_Args>(__args)...);
+    _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__newval), _CUDA_VSTD::forward<_Args>(__args)...);
   }
 
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _T1, class _T2, class... _Args)
   _CCCL_REQUIRES(
     (!_CCCL_TRAIT(is_nothrow_constructible, _T1, _Args...)) _CCCL_AND _CCCL_TRAIT(is_nothrow_move_constructible, _T1))
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void
-  __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args)
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args)
   {
     _T1 __tmp(_CUDA_VSTD::forward<_Args>(__args)...);
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__oldval));
-    _LIBCUDACXX_CONSTRUCT_AT(__newval, _CUDA_VSTD::move(__tmp));
+    _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__newval), _CUDA_VSTD::move(__tmp));
   }
 
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _T1, class _T2, class... _Args)
   _CCCL_REQUIRES(
     (!_CCCL_TRAIT(is_nothrow_constructible, _T1, _Args...)) _CCCL_AND(!_CCCL_TRAIT(is_nothrow_move_constructible, _T1)))
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void
-  __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args)
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void __reinit_expected(_T1& __newval, _T2& __oldval, _Args&&... __args)
   {
     static_assert(
       _CCCL_TRAIT(is_nothrow_move_constructible, _T2),
@@ -481,27 +482,28 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
     _T2 __tmp(_CUDA_VSTD::move(__oldval));
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__oldval));
     auto __trans = _CUDA_VSTD::__make_exception_guard([&] {
-      _LIBCUDACXX_CONSTRUCT_AT(__oldval, _CUDA_VSTD::move(__tmp));
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__oldval), _CUDA_VSTD::move(__tmp));
     });
-    _LIBCUDACXX_CONSTRUCT_AT(__newval, _CUDA_VSTD::forward<_Args>(__args)...);
+    _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__newval), _CUDA_VSTD::forward<_Args>(__args)...);
     __trans.__complete();
   }
 
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Err2 = _Err)
   _CCCL_REQUIRES(_CCCL_TRAIT(is_nothrow_move_constructible, _Err2))
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void
   __swap_val_unex_impl(__expected_storage<_Tp, _Err2>& __with_val, __expected_storage& __with_err)
   {
     _Err __tmp(_CUDA_VSTD::move(__with_err.__union_.__unex_));
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__with_err.__union_.__unex_));
     auto __trans = _CUDA_VSTD::__make_exception_guard([&] {
-      _LIBCUDACXX_CONSTRUCT_AT(__with_err.__union_.__unex_, _CUDA_VSTD::move(__tmp));
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__with_err.__union_.__unex_), _CUDA_VSTD::move(__tmp));
     });
-    _LIBCUDACXX_CONSTRUCT_AT(__with_err.__union_.__val_, _CUDA_VSTD::move(__with_val.__union_.__val_));
+    _CUDA_VSTD::__construct_at(
+      _CUDA_VSTD::addressof(__with_err.__union_.__val_), _CUDA_VSTD::move(__with_val.__union_.__val_));
     __trans.__complete();
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__with_val.__union_.__val_));
-    _LIBCUDACXX_CONSTRUCT_AT(__with_val.__union_.__unex_, _CUDA_VSTD::move(__tmp));
+    _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__with_val.__union_.__unex_), _CUDA_VSTD::move(__tmp));
     __with_val.__has_val_ = false;
     __with_err.__has_val_ = true;
   }
@@ -509,7 +511,7 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_TEMPLATE(class _Err2 = _Err)
   _CCCL_REQUIRES((!_CCCL_TRAIT(is_nothrow_move_constructible, _Err2)))
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void
   __swap_val_unex_impl(__expected_storage<_Tp, _Err2>& __with_val, __expected_storage& __with_err)
   {
     static_assert(_CCCL_TRAIT(is_nothrow_move_constructible, _Tp),
@@ -518,19 +520,20 @@ struct __expected_storage : __expected_destruct<_Tp, _Err>
     _Tp __tmp(_CUDA_VSTD::move(__with_val.__union_.__val_));
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__with_val.__union_.__val_));
     auto __trans = _CUDA_VSTD::__make_exception_guard([&] {
-      _LIBCUDACXX_CONSTRUCT_AT(__with_val.__union_.__val_, _CUDA_VSTD::move(__tmp));
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__with_val.__union_.__val_), _CUDA_VSTD::move(__tmp));
     });
-    _LIBCUDACXX_CONSTRUCT_AT(__with_val.__union_.__unex_, _CUDA_VSTD::move(__with_err.__union_.__unex_));
+    _CUDA_VSTD::__construct_at(
+      _CUDA_VSTD::addressof(__with_val.__union_.__unex_), _CUDA_VSTD::move(__with_err.__union_.__unex_));
     __trans.__complete();
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__with_err.__union_.__unex_));
-    _LIBCUDACXX_CONSTRUCT_AT(__with_err.__union_.__val_, _CUDA_VSTD::move(__tmp));
+    _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(__with_err.__union_.__val_), _CUDA_VSTD::move(__tmp));
     __with_val.__has_val_ = false;
     __with_err.__has_val_ = true;
   }
 };
 
 template <class _Tp, class _Err>
-_CCCL_INLINE_VAR constexpr __smf_availability __expected_can_copy_construct =
+inline constexpr __smf_availability __expected_can_copy_construct =
   (_CCCL_TRAIT(is_trivially_copy_constructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
       && _CCCL_TRAIT(is_trivially_copy_constructible, _Err)
     ? __smf_availability::__trivial
@@ -550,17 +553,17 @@ struct __expected_copy<_Tp, _Err, __smf_availability::__available> : __expected_
 {
   _LIBCUDACXX_DELEGATE_CONSTRUCTORS(__expected_copy, __expected_storage, _Tp, _Err);
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_copy(const __expected_copy& __other) noexcept(
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_copy(const __expected_copy& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_copy_constructible, _Tp) && _CCCL_TRAIT(is_nothrow_copy_constructible, _Err))
       : __base(__other.__has_val_)
   {
     if (__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__val_, __other.__union_.__val_);
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(this->__union_.__val_), __other.__union_.__val_);
     }
     else
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, __other.__union_.__unex_);
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(this->__union_.__unex_), __other.__union_.__unex_);
     }
   }
 
@@ -581,7 +584,7 @@ struct __expected_copy<_Tp, _Err, __smf_availability::__deleted> : __expected_st
 };
 
 template <class _Tp, class _Err>
-_CCCL_INLINE_VAR constexpr __smf_availability __expected_can_move_construct =
+inline constexpr __smf_availability __expected_can_move_construct =
   (_CCCL_TRAIT(is_trivially_move_constructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
       && _CCCL_TRAIT(is_trivially_move_constructible, _Err)
     ? __smf_availability::__trivial
@@ -603,17 +606,19 @@ struct __expected_move<_Tp, _Err, __smf_availability::__available> : __expected_
 
   _CCCL_HIDE_FROM_ABI __expected_move(const __expected_move&) = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_move(__expected_move&& __other) noexcept(
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_move(__expected_move&& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_move_constructible, _Tp) && _CCCL_TRAIT(is_nothrow_move_constructible, _Err))
       : __base(__other.__has_val_)
   {
     if (__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__val_, _CUDA_VSTD::move(__other.__union_.__val_));
+      _CUDA_VSTD::__construct_at(
+        _CUDA_VSTD::addressof(this->__union_.__val_), _CUDA_VSTD::move(__other.__union_.__val_));
     }
     else
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, _CUDA_VSTD::move(__other.__union_.__unex_));
+      _CUDA_VSTD::__construct_at(
+        _CUDA_VSTD::addressof(this->__union_.__unex_), _CUDA_VSTD::move(__other.__union_.__unex_));
     }
   }
 
@@ -634,7 +639,7 @@ struct __expected_move<_Tp, _Err, __smf_availability::__deleted> : __expected_co
 
 // Need to also check against is_nothrow_move_constructible in the trivial case as that is stupidly in the constraints
 template <class _Tp, class _Err>
-_CCCL_INLINE_VAR constexpr __smf_availability __expected_can_copy_assign =
+inline constexpr __smf_availability __expected_can_copy_assign =
   (_CCCL_TRAIT(is_trivially_destructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
       && _CCCL_TRAIT(is_trivially_destructible, _Err)
       && (_CCCL_TRAIT(is_trivially_copy_constructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
@@ -668,7 +673,7 @@ struct __expected_copy_assign<_Tp, _Err, __smf_availability::__available> : __ex
   _CCCL_HIDE_FROM_ABI __expected_copy_assign(__expected_copy_assign&&)      = default;
 
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_copy_assign&
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_copy_assign&
   operator=(const __expected_copy_assign& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_copy_assignable, _Tp) && _CCCL_TRAIT(is_nothrow_copy_constructible, _Tp)
     && _CCCL_TRAIT(is_nothrow_copy_assignable, _Err)
@@ -710,7 +715,7 @@ struct __expected_copy_assign<_Tp, _Err, __smf_availability::__deleted> : __expe
 };
 
 template <class _Tp, class _Err>
-_CCCL_INLINE_VAR constexpr __smf_availability __expected_can_move_assign =
+inline constexpr __smf_availability __expected_can_move_assign =
   (_CCCL_TRAIT(is_trivially_destructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
       && _CCCL_TRAIT(is_trivially_destructible, _Err)
       && (_CCCL_TRAIT(is_trivially_move_constructible, _Tp) || _CCCL_TRAIT(is_same, _Tp, void))
@@ -742,8 +747,8 @@ struct __expected_move_assign<_Tp, _Err, __smf_availability::__available> : __ex
   _CCCL_HIDE_FROM_ABI __expected_move_assign(__expected_move_assign&&)                 = default;
   _CCCL_HIDE_FROM_ABI __expected_move_assign& operator=(const __expected_move_assign&) = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_move_assign&
-  operator=(__expected_move_assign&& __other) noexcept(
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_move_assign& operator=(__expected_move_assign&& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_move_assignable, _Tp) && _CCCL_TRAIT(is_nothrow_move_constructible, _Tp)
     && _CCCL_TRAIT(is_nothrow_move_assignable, _Err)
     && _CCCL_TRAIT(is_nothrow_move_constructible, _Err)) // strengthened
@@ -794,18 +799,20 @@ struct __expected_destruct<void, _Err, false, false>
     struct __empty_t
     {};
 
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept
+    _CCCL_API constexpr __expected_union_t() noexcept
         : __empty_()
     {}
 
+    _CCCL_EXEC_CHECK_DISABLE
     template <class... _Args>
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
+    _CCCL_API constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
       _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
         : __unex_(_CUDA_VSTD::forward<_Args>(__args)...)
     {}
 
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _Fun, class... _Args>
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+    _CCCL_API constexpr __expected_union_t(
       __expected_construct_from_invoke_tag,
       unexpect_t,
       _Fun&& __fun,
@@ -815,7 +822,7 @@ struct __expected_destruct<void, _Err, false, false>
 
     // the __expected_destruct's destructor handles this
     _CCCL_EXEC_CHECK_DISABLE
-    _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_union_t() {}
+    _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_union_t() {}
 
     _CCCL_NO_UNIQUE_ADDRESS __empty_t __empty_;
     _CCCL_NO_UNIQUE_ADDRESS _Err __unex_;
@@ -824,19 +831,21 @@ struct __expected_destruct<void, _Err, false, false>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept
       : __has_val_(__has_val)
   {}
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -849,7 +858,7 @@ struct __expected_destruct<void, _Err, false, false>
   {}
 
   _CCCL_EXEC_CHECK_DISABLE
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 ~__expected_destruct()
   {
     if (!__has_val_)
     {
@@ -867,18 +876,20 @@ struct __expected_destruct<void, _Err, false, true>
     struct __empty_t
     {};
 
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t() noexcept
+    _CCCL_API constexpr __expected_union_t() noexcept
         : __empty_()
     {}
 
+    _CCCL_EXEC_CHECK_DISABLE
     template <class... _Args>
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
+    _CCCL_API constexpr __expected_union_t(unexpect_t, _Args&&... __args) noexcept(
       _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
         : __unex_(_CUDA_VSTD::forward<_Args>(__args)...)
     {}
 
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _Fun, class... _Args>
-    _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_union_t(
+    _CCCL_API constexpr __expected_union_t(
       __expected_construct_from_invoke_tag,
       unexpect_t,
       _Fun&& __fun,
@@ -893,22 +904,24 @@ struct __expected_destruct<void, _Err, false, true>
 
   _CCCL_HIDE_FROM_ABI constexpr __expected_destruct() = default;
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(in_place_t) noexcept(
-    _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
+  _CCCL_API constexpr __expected_destruct(in_place_t) noexcept(_CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_()
       , __has_val_(true)
   {}
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
+  _CCCL_API constexpr __expected_destruct(unexpect_t, _Args&&... __args) noexcept(
     _CCCL_TRAIT(is_nothrow_constructible, _Err, _Args...))
       : __union_(unexpect, _CUDA_VSTD::forward<_Args>(__args)...)
       , __has_val_(false)
   {}
 
+  _CCCL_EXEC_CHECK_DISABLE
   template <class _Fun, class... _Args>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(
+  _CCCL_API constexpr __expected_destruct(
     __expected_construct_from_invoke_tag,
     unexpect_t,
     _Fun&& __fun,
@@ -920,7 +933,7 @@ struct __expected_destruct<void, _Err, false, true>
       , __has_val_(false)
   {}
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __expected_destruct(const bool __has_val) noexcept
+  _CCCL_API constexpr __expected_destruct(const bool __has_val) noexcept
       : __has_val_(__has_val)
   {}
 };
@@ -933,11 +946,12 @@ struct __expected_storage<void, _Err> : __expected_destruct<void, _Err>
   _LIBCUDACXX_DELEGATE_CONSTRUCTORS(__expected_storage, __expected_destruct, void, _Err);
 
   _CCCL_EXEC_CHECK_DISABLE
-  static _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 void __swap_val_unex_impl(
+  static _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void __swap_val_unex_impl(
     __expected_storage& __with_val,
     __expected_storage& __with_err) noexcept(_CCCL_TRAIT(is_nothrow_move_constructible, _Err))
   {
-    _LIBCUDACXX_CONSTRUCT_AT(__with_val.__union_.__unex_, _CUDA_VSTD::move(__with_err.__union_.__unex_));
+    _CUDA_VSTD::__construct_at(
+      _CUDA_VSTD::addressof(__with_val.__union_.__unex_), _CUDA_VSTD::move(__with_err.__union_.__unex_));
     _CUDA_VSTD::__destroy_at(_CUDA_VSTD::addressof(__with_err.__union_.__unex_));
     __with_val.__has_val_ = false;
     __with_err.__has_val_ = true;
@@ -949,13 +963,13 @@ struct __expected_copy<void, _Err, __smf_availability::__available> : __expected
 {
   _LIBCUDACXX_DELEGATE_CONSTRUCTORS(__expected_copy, __expected_storage, void, _Err);
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20
   __expected_copy(const __expected_copy& __other) noexcept(_CCCL_TRAIT(is_nothrow_copy_constructible, _Err))
       : __base(__other.__has_val_)
   {
     if (!__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, __other.__union_.__unex_);
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(this->__union_.__unex_), __other.__union_.__unex_);
     }
   }
 
@@ -971,13 +985,14 @@ struct __expected_move<void, _Err, __smf_availability::__available> : __expected
 
   _CCCL_HIDE_FROM_ABI __expected_move(const __expected_move&) = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20
   __expected_move(__expected_move&& __other) noexcept(_CCCL_TRAIT(is_nothrow_move_constructible, _Err))
       : __base(__other.__has_val_)
   {
     if (!__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, _CUDA_VSTD::move(__other.__union_.__unex_));
+      _CUDA_VSTD::__construct_at(
+        _CUDA_VSTD::addressof(this->__union_.__unex_), _CUDA_VSTD::move(__other.__union_.__unex_));
     }
   }
 
@@ -993,7 +1008,8 @@ struct __expected_copy_assign<void, _Err, __smf_availability::__available> : __e
   _CCCL_HIDE_FROM_ABI __expected_copy_assign(const __expected_copy_assign&) = default;
   _CCCL_HIDE_FROM_ABI __expected_copy_assign(__expected_copy_assign&&)      = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_copy_assign&
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_copy_assign&
   operator=(const __expected_copy_assign& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_copy_assignable, _Err) && _CCCL_TRAIT(is_nothrow_copy_constructible, _Err)) // strengthened
   {
@@ -1003,7 +1019,7 @@ struct __expected_copy_assign<void, _Err, __smf_availability::__available> : __e
     }
     else if (this->__has_val_ && !__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, __other.__union_.__unex_);
+      _CUDA_VSTD::__construct_at(_CUDA_VSTD::addressof(this->__union_.__unex_), __other.__union_.__unex_);
       this->__has_val_ = false;
     }
     else if (!this->__has_val_ && __other.__has_val_)
@@ -1030,8 +1046,8 @@ struct __expected_move_assign<void, _Err, __smf_availability::__available> : __e
   _CCCL_HIDE_FROM_ABI __expected_move_assign(__expected_move_assign&&)                 = default;
   _CCCL_HIDE_FROM_ABI __expected_move_assign& operator=(const __expected_move_assign&) = default;
 
-  _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX20 __expected_move_assign&
-  operator=(__expected_move_assign&& __other) noexcept(
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_API inline _CCCL_CONSTEXPR_CXX20 __expected_move_assign& operator=(__expected_move_assign&& __other) noexcept(
     _CCCL_TRAIT(is_nothrow_move_assignable, _Err) && _CCCL_TRAIT(is_nothrow_move_constructible, _Err)) // strengthened
   {
     if (this->__has_val_ && __other.__has_val_)
@@ -1040,7 +1056,8 @@ struct __expected_move_assign<void, _Err, __smf_availability::__available> : __e
     }
     else if (this->__has_val_ && !__other.__has_val_)
     {
-      _LIBCUDACXX_CONSTRUCT_AT(this->__union_.__unex_, _CUDA_VSTD::move(__other.__union_.__unex_));
+      _CUDA_VSTD::__construct_at(
+        _CUDA_VSTD::addressof(this->__union_.__unex_), _CUDA_VSTD::move(__other.__union_.__unex_));
       this->__has_val_ = false;
     }
     else if (!this->__has_val_ && __other.__has_val_)
@@ -1058,4 +1075,6 @@ struct __expected_move_assign<void, _Err, __smf_availability::__available> : __e
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___EXPECTED_EXPECTED_BASE_H
