@@ -23,12 +23,23 @@
 
 #include <cuda/std/cstddef>
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-_CCCL_INLINE_VAR constexpr size_t dynamic_extent = static_cast<size_t>(-1);
+inline constexpr size_t dynamic_extent = static_cast<size_t>(-1);
+
 template <typename _Tp, size_t _Extent = dynamic_extent>
 class span;
 
+template <class _Tp>
+inline constexpr bool __is_std_span_v = false;
+
+template <class _Tp, size_t _Extent>
+inline constexpr bool __is_std_span_v<span<_Tp, _Extent>> = true;
+
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___FWD_SPAN_H
