@@ -53,6 +53,7 @@
 #  endif
 
 #  if _CCCL_STD_VER >= 2020
+#    include <cuda/std/__cccl/prologue.h>
 template <class _Tp, class = void>
 struct __cccl_type_is_defined : _CUDA_VSTD::false_type
 {};
@@ -67,13 +68,17 @@ namespace std
 struct __cccl_std_contiguous_iterator_tag_exists : __cccl_type_is_defined<struct contiguous_iterator_tag>
 {};
 } // namespace std
+
+#    include <cuda/std/__cccl/epilogue.h>
 #  endif // _CCCL_STD_VER >= 2020
 
 #endif // !_CCCL_COMPILER(NVRTC)
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if !defined(_CCCL_NO_CONCEPTS)
+#if _CCCL_HAS_CONCEPTS()
 
 template <class _Tp>
 using __with_reference = _Tp&;
@@ -90,7 +95,7 @@ concept __dereferenceable = requires(_Tp& __t) {
 template <__dereferenceable _Tp>
 using iter_reference_t = decltype(*declval<_Tp&>());
 
-#else // ^^^ _CCCL_NO_CONCEPTS ^^^ // vvv !_CCCL_NO_CONCEPTS vvv
+#else // ^^^ _CCCL_HAS_CONCEPTS() ^^^ // vvv _CCCL_HAS_CONCEPTS() vvv
 
 template <class _Tp>
 using __with_reference = _Tp&;
@@ -114,7 +119,7 @@ _CCCL_CONCEPT __dereferenceable = _CCCL_FRAGMENT(__dereferenceable_, _Tp);
 template <class _Tp>
 using iter_reference_t = enable_if_t<__dereferenceable<_Tp>, decltype(*declval<_Tp&>())>;
 
-#endif // !_CCCL_NO_CONCEPTS
+#endif // _CCCL_HAS_CONCEPTS()
 
 #if _CCCL_COMPILER(NVRTC)
 
@@ -164,58 +169,55 @@ using _ITER_TRAITS = typename __iter_traits_cache<_Iter>::type;
 #if defined(_GLIBCXX_DEBUG)
 _CCCL_TEMPLATE(class _Iter, class _Ty, class _Range)
 _CCCL_REQUIRES(_IsSame<_Iter, ::__gnu_debug::_Safe_iterator<_Ty*, _Range>>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(::__gnu_debug::_Safe_iterator<_Ty*, _Range>, __priority_tag<3>)
+_CCCL_API inline auto __iter_concept_fn(::__gnu_debug::_Safe_iterator<_Ty*, _Range>, __priority_tag<3>)
   -> contiguous_iterator_tag;
 #endif // _GLIBCXX_DEBUG
 #if defined(__GLIBCXX__)
 _CCCL_TEMPLATE(class _Iter, class _Ty, class _Range)
 _CCCL_REQUIRES(_IsSame<_Iter, ::__gnu_cxx::__normal_iterator<_Ty*, _Range>>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(::__gnu_cxx::__normal_iterator<_Ty*, _Range>, __priority_tag<3>)
+_CCCL_API inline auto __iter_concept_fn(::__gnu_cxx::__normal_iterator<_Ty*, _Range>, __priority_tag<3>)
   -> contiguous_iterator_tag;
 #endif // __GLIBCXX__
 #if defined(_LIBCPP_VERSION)
 _CCCL_TEMPLATE(class _Iter, class _Ty)
 _CCCL_REQUIRES(_IsSame<_Iter, ::std::__wrap_iter<_Ty*>>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(::std::__wrap_iter<_Ty*>, __priority_tag<3>)
-  -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(::std::__wrap_iter<_Ty*>, __priority_tag<3>) -> contiguous_iterator_tag;
 #elif defined(_MSVC_STL_VERSION) || defined(_IS_WRS)
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_Array_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_Array_const_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_Vector_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_Vector_const_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_String_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_String_const_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_String_view_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 _CCCL_TEMPLATE(class _Iter)
 _CCCL_REQUIRES(_IsSame<_Iter, class _Iter::_Span_iterator>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<3>) -> contiguous_iterator_tag;
 #endif // _MSVC_STL_VERSION
 _CCCL_TEMPLATE(class _Iter, class _Ty)
 _CCCL_REQUIRES(_IsSame<_Iter, _Ty*>::value)
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Ty*, __priority_tag<3>) -> contiguous_iterator_tag;
+_CCCL_API inline auto __iter_concept_fn(_Ty*, __priority_tag<3>) -> contiguous_iterator_tag;
 
 template <class _Iter>
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<2>) ->
-  typename _ITER_TRAITS<_Iter>::iterator_concept;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<2>) -> typename _ITER_TRAITS<_Iter>::iterator_concept;
 template <class _Iter>
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<1>) ->
-  typename _ITER_TRAITS<_Iter>::iterator_category;
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<1>) -> typename _ITER_TRAITS<_Iter>::iterator_category;
 template <class _Iter>
-_LIBCUDACXX_HIDE_FROM_ABI auto __iter_concept_fn(_Iter, __priority_tag<0>)
+_CCCL_API inline auto __iter_concept_fn(_Iter, __priority_tag<0>)
   -> enable_if_t<__is_primary_cccl_template<_Iter>::value && __is_primary_std_template<_Iter>::value,
                  random_access_iterator_tag>;
 
@@ -240,9 +242,9 @@ struct __has_iterator_category
 {
 private:
   template <class _Up>
-  _LIBCUDACXX_HIDE_FROM_ABI static false_type __test(...);
+  _CCCL_API inline static false_type __test(...);
   template <class _Up>
-  _LIBCUDACXX_HIDE_FROM_ABI static true_type __test(typename _Up::iterator_category* = nullptr);
+  _CCCL_API inline static true_type __test(typename _Up::iterator_category* = nullptr);
 
 public:
   static const bool value = decltype(__test<_Tp>(nullptr))::value;
@@ -253,15 +255,15 @@ struct __has_iterator_concept
 {
 private:
   template <class _Up>
-  _LIBCUDACXX_HIDE_FROM_ABI static false_type __test(...);
+  _CCCL_API inline static false_type __test(...);
   template <class _Up>
-  _LIBCUDACXX_HIDE_FROM_ABI static true_type __test(typename _Up::iterator_concept* = nullptr);
+  _CCCL_API inline static true_type __test(typename _Up::iterator_concept* = nullptr);
 
 public:
   static const bool value = decltype(__test<_Tp>(nullptr))::value;
 };
 
-#if !defined(_CCCL_NO_CONCEPTS)
+#if _CCCL_HAS_CONCEPTS()
 
 // The `cpp17-*-iterator` exposition-only concepts have very similar names to the `Cpp17*Iterator` named requirements
 // from `[iterator.cpp17]`. To avoid confusion between the two, the exposition-only concepts have been banished to
@@ -515,7 +517,7 @@ struct _CCCL_TYPE_VISIBILITY_DEFAULT iterator_traits : __iterator_traits<_Ip>
   using __cccl_primary_template = iterator_traits;
 };
 
-#else // ^^^ !_CCCL_NO_CONCEPTS ^^^ / vvv _CCCL_NO_CONCEPTS vvv
+#else // ^^^ _CCCL_HAS_CONCEPTS() ^^^ / vvv !_CCCL_HAS_CONCEPTS() vvv
 
 // The `cpp17-*-iterator` exposition-only concepts have very similar names to the `Cpp17*Iterator` named requirements
 // from `[iterator.cpp17]`. To avoid confusion between the two, the exposition-only concepts have been banished to
@@ -592,25 +594,25 @@ _CCCL_CONCEPT __cpp17_random_access_iterator =
 
 // We need to consider if a user has specialized std::iterator_traits
 template <class _Ip>
-_CCCL_INLINE_VAR constexpr bool __specialized_from_std = !__is_primary_std_template<remove_cvref_t<_Ip>>::value;
+inline constexpr bool __specialized_from_std = !__is_primary_std_template<remove_cvref_t<_Ip>>::value;
 
 template <class, class = void>
-_CCCL_INLINE_VAR constexpr bool __has_member_reference = false;
+inline constexpr bool __has_member_reference = false;
 
 template <class _Tp>
-_CCCL_INLINE_VAR constexpr bool __has_member_reference<_Tp, void_t<typename _Tp::reference>> = true;
+inline constexpr bool __has_member_reference<_Tp, void_t<typename _Tp::reference>> = true;
 
 template <class, class = void>
-_CCCL_INLINE_VAR constexpr bool __has_member_pointer = false;
+inline constexpr bool __has_member_pointer = false;
 
 template <class _Tp>
-_CCCL_INLINE_VAR constexpr bool __has_member_pointer<_Tp, void_t<typename _Tp::pointer>> = true;
+inline constexpr bool __has_member_pointer<_Tp, void_t<typename _Tp::pointer>> = true;
 
 template <class, class = void>
-_CCCL_INLINE_VAR constexpr bool __has_member_iterator_category = false;
+inline constexpr bool __has_member_iterator_category = false;
 
 template <class _Tp>
-_CCCL_INLINE_VAR constexpr bool __has_member_iterator_category<_Tp, void_t<typename _Tp::iterator_category>> = true;
+inline constexpr bool __has_member_iterator_category<_Tp, void_t<typename _Tp::iterator_category>> = true;
 
 template <class _Ip>
 _CCCL_CONCEPT __specifies_members =
@@ -653,7 +655,7 @@ struct __iterator_traits_member_pointer_or_arrow_or_void<_Ip, enable_if_t<__has_
 };
 
 template <class _Ip>
-_CCCL_CONCEPT_FRAGMENT(__has_operator_arrow_, requires(_Ip& __i)(__i.operator->()));
+_CCCL_CONCEPT_FRAGMENT(__has_operator_arrow_, requires(_Ip& __i)(__cccl_unused(__i.operator->())));
 
 template <class _Ip>
 _CCCL_CONCEPT __has_operator_arrow = _CCCL_FRAGMENT(__has_operator_arrow_, _Ip);
@@ -805,12 +807,12 @@ struct _CCCL_TYPE_VISIBILITY_DEFAULT iterator_traits : __iterator_traits<_Ip>
   using __cccl_primary_template = iterator_traits;
 };
 
-#endif // !_CCCL_NO_CONCEPTS
+#endif // _CCCL_HAS_CONCEPTS()
 
 template <class _Tp>
-#if !defined(_CCCL_NO_CONCEPTS)
+#if _CCCL_HAS_CONCEPTS()
   requires is_object_v<_Tp>
-#endif // !_CCCL_NO_CONCEPTS
+#endif // _CCCL_HAS_CONCEPTS()
 struct _CCCL_TYPE_VISIBILITY_DEFAULT iterator_traits<_Tp*>
 {
   using difference_type   = ptrdiff_t;
@@ -821,81 +823,50 @@ struct _CCCL_TYPE_VISIBILITY_DEFAULT iterator_traits<_Tp*>
   using iterator_concept  = contiguous_iterator_tag;
 };
 
-template <class _Tp, class _Up, bool = __has_iterator_category<iterator_traits<_Tp>>::value>
-struct __has_iterator_category_convertible_to : is_convertible<typename iterator_traits<_Tp>::iterator_category, _Up>
-{};
+template <class _Iter, class _Tag>
+_CCCL_CONCEPT __has_iterator_category_convertible_to = _CCCL_REQUIRES_EXPR((_Iter, _Tag)) //
+  (typename(typename iterator_traits<_Iter>::iterator_category),
+   requires(is_convertible_v<typename iterator_traits<_Iter>::iterator_category, _Tag>));
 
-template <class _Tp, class _Up>
-struct __has_iterator_category_convertible_to<_Tp, _Up, false> : false_type
-{};
+template <class _Iter, class _Tag>
+_CCCL_CONCEPT __has_iterator_concept_convertible_to = _CCCL_REQUIRES_EXPR((_Iter, _Tag)) //
+  (typename(typename _Iter::iterator_concept), requires(is_convertible_v<typename _Iter::iterator_concept, _Tag>));
 
-template <class _Tp, class _Up, bool = __has_iterator_concept<_Tp>::value>
-struct __has_iterator_concept_convertible_to : is_convertible<typename _Tp::iterator_concept, _Up>
-{};
+template <class _Iter>
+inline constexpr bool __has_input_traversal =
+  __has_iterator_category_convertible_to<_Iter, input_iterator_tag>
+  || __has_iterator_concept_convertible_to<_Iter, input_iterator_tag>;
 
-template <class _Tp, class _Up>
-struct __has_iterator_concept_convertible_to<_Tp, _Up, false> : false_type
-{};
+template <class _Iter>
+inline constexpr bool __has_forward_traversal =
+  __has_iterator_category_convertible_to<_Iter, forward_iterator_tag>
+  || __has_iterator_concept_convertible_to<_Iter, forward_iterator_tag>;
 
-template <class _Tp>
-struct __is_cpp17_input_iterator : public __has_iterator_category_convertible_to<_Tp, input_iterator_tag>
-{};
+template <class _Iter>
+inline constexpr bool __has_bidirectional_traversal =
+  __has_iterator_category_convertible_to<_Iter, bidirectional_iterator_tag>
+  || __has_iterator_concept_convertible_to<_Iter, bidirectional_iterator_tag>;
 
-template <class _Tp>
-struct __is_cpp17_forward_iterator : public __has_iterator_category_convertible_to<_Tp, forward_iterator_tag>
-{};
+template <class _Iter>
+inline constexpr bool __has_random_access_traversal =
+  __has_iterator_category_convertible_to<_Iter, random_access_iterator_tag>
+  || __has_iterator_concept_convertible_to<_Iter, random_access_iterator_tag>;
 
-template <class _Tp>
-struct __is_cpp17_bidirectional_iterator
-    : public __has_iterator_category_convertible_to<_Tp, bidirectional_iterator_tag>
-{};
-
-template <class _Tp>
-struct __is_cpp17_random_access_iterator
-    : public __has_iterator_category_convertible_to<_Tp, random_access_iterator_tag>
-{};
-
-// __is_cpp17_contiguous_iterator determines if an iterator is known by
+// __has_contiguous_traversal determines if an iterator is known by
 // libc++ to be contiguous, either because it advertises itself as such
 // (in C++20) or because it is a pointer type or a known trivial wrapper
 // around a (possibly fancy) pointer type, such as __wrap_iter<T*>.
 // Such iterators receive special "contiguous" optimizations in
 // std::copy and std::sort.
 //
-template <class _Tp>
-struct __is_cpp17_contiguous_iterator
-    : _Or<__has_iterator_category_convertible_to<_Tp, contiguous_iterator_tag>,
-          __has_iterator_concept_convertible_to<_Tp, contiguous_iterator_tag>>
-{};
+template <class _Iter>
+inline constexpr bool __has_contiguous_traversal =
+  __has_iterator_category_convertible_to<_Iter, contiguous_iterator_tag>
+  || __has_iterator_concept_convertible_to<_Iter, contiguous_iterator_tag>;
 
 // Any native pointer which is an iterator is also a contiguous iterator.
-template <class _Up>
-struct __is_cpp17_contiguous_iterator<_Up*> : true_type
-{};
-
-template <class _Iter>
-class __wrap_iter;
-
 template <class _Tp>
-struct __is_exactly_cpp17_input_iterator
-    : public integral_constant<bool,
-                               __has_iterator_category_convertible_to<_Tp, input_iterator_tag>::value
-                                 && !__has_iterator_category_convertible_to<_Tp, forward_iterator_tag>::value>
-{};
-
-template <class _Tp>
-struct __is_exactly_cpp17_forward_iterator
-    : public integral_constant<bool,
-                               __has_iterator_category_convertible_to<_Tp, forward_iterator_tag>::value
-                                 && !__has_iterator_category_convertible_to<_Tp, bidirectional_iterator_tag>::value>
-{};
-
-template <class _Tp>
-struct __is_exactly_cpp17_bidirectional_iterator
-    : public integral_constant<bool,
-                               __has_iterator_category_convertible_to<_Tp, bidirectional_iterator_tag>::value
-                                 && !__has_iterator_category_convertible_to<_Tp, random_access_iterator_tag>::value>
-{};
+inline constexpr bool __has_contiguous_traversal<_Tp*> = true;
 
 template <class _InputIterator>
 using __iter_value_type = typename iterator_traits<_InputIterator>::value_type;
@@ -925,4 +896,6 @@ using __iter_value_type = typename iterator_traits<_InputIterator>::value_type;
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___ITERATOR_ITERATOR_TRAITS_H
