@@ -1,8 +1,6 @@
-// -*- C++ -*-
 //===----------------------------------------------------------------------===//
 //
-// Part of libcu++, the C++ Standard Library for your entire system,
-// under the Apache License v2.0 with LLVM Exceptions.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 // SPDX-FileCopyrightText: Copyright (c) 2025 NVIDIA CORPORATION & AFFILIATES.
@@ -27,8 +25,11 @@
 #include <cuda/std/__type_traits/is_floating_point.h>
 #include <cuda/std/__type_traits/is_integral.h>
 #include <cuda/std/__type_traits/is_same.h>
+#include <cuda/std/cfloat>
 #include <cuda/std/climits>
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 enum float_round_style
@@ -40,7 +41,7 @@ enum float_round_style
   round_toward_neg_infinity = 3
 };
 
-enum float_denorm_style
+enum _LIBCUDACXX_DEPRECATED_IN_CXX23 float_denorm_style
 {
   denorm_indeterminate = -1,
   denorm_absent        = 0,
@@ -56,9 +57,8 @@ enum class __numeric_limits_type
 };
 
 template <class _Tp>
-_LIBCUDACXX_HIDE_FROM_ABI constexpr __numeric_limits_type __make_numeric_limits_type()
+_CCCL_API constexpr __numeric_limits_type __make_numeric_limits_type()
 {
-#if !defined(_CCCL_NO_IF_CONSTEXPR)
   if constexpr (_CCCL_TRAIT(is_same, _Tp, bool))
   {
     return __numeric_limits_type::__bool;
@@ -75,15 +75,6 @@ _LIBCUDACXX_HIDE_FROM_ABI constexpr __numeric_limits_type __make_numeric_limits_
   {
     return __numeric_limits_type::__other;
   }
-#else // ^^^ !_CCCL_NO_IF_CONSTEXPR ^^^ // vvv _CCCL_NO_IF_CONSTEXPR vvv
-  return _CCCL_TRAIT(is_same, _Tp, bool)
-         ? __numeric_limits_type::__bool
-         : (_CCCL_TRAIT(is_integral, _Tp)
-              ? __numeric_limits_type::__integral
-              : (_CCCL_TRAIT(is_floating_point, _Tp) || _CCCL_TRAIT(__is_extended_floating_point, _Tp)
-                   ? __numeric_limits_type::__floating_point
-                   : __numeric_limits_type::__other));
-#endif // _CCCL_NO_IF_CONSTEXPR
 }
 
 template <class _Tp, __numeric_limits_type = __make_numeric_limits_type<_Tp>()>
@@ -93,15 +84,15 @@ public:
   using type = _Tp;
 
   static constexpr bool is_specialized = false;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return type();
   }
@@ -113,11 +104,11 @@ public:
   static constexpr bool is_integer  = false;
   static constexpr bool is_exact    = false;
   static constexpr int radix        = 0;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  _CCCL_API static constexpr type epsilon() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return type();
   }
@@ -127,24 +118,24 @@ public:
   static constexpr int max_exponent   = 0;
   static constexpr int max_exponent10 = 0;
 
-  static constexpr bool has_infinity             = false;
-  static constexpr bool has_quiet_NaN            = false;
-  static constexpr bool has_signaling_NaN        = false;
-  static constexpr float_denorm_style has_denorm = denorm_absent;
-  static constexpr bool has_denorm_loss          = false;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  static constexpr bool has_infinity                                             = false;
+  static constexpr bool has_quiet_NaN                                            = false;
+  static constexpr bool has_signaling_NaN                                        = false;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_absent;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return type();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
     return type();
   }
@@ -183,18 +174,18 @@ public:
   static constexpr bool is_specialized = true;
 
   static constexpr bool is_signed   = type(-1) < type(0);
-  static constexpr int digits       = static_cast<int>(sizeof(type) * __CHAR_BIT__ - is_signed);
+  static constexpr int digits       = static_cast<int>(sizeof(type) * CHAR_BIT - is_signed);
   static constexpr int digits10     = digits * 3 / 10;
   static constexpr int max_digits10 = 0;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
     return __int_min<type, digits, is_signed>::value;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
     return is_signed ? type(type(~0) ^ min()) : type(~0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return min();
   }
@@ -202,11 +193,11 @@ public:
   static constexpr bool is_integer = true;
   static constexpr bool is_exact   = true;
   static constexpr int radix       = 2;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  _CCCL_API static constexpr type epsilon() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return type(0);
   }
@@ -216,24 +207,24 @@ public:
   static constexpr int max_exponent   = 0;
   static constexpr int max_exponent10 = 0;
 
-  static constexpr bool has_infinity             = false;
-  static constexpr bool has_quiet_NaN            = false;
-  static constexpr bool has_signaling_NaN        = false;
-  static constexpr float_denorm_style has_denorm = denorm_absent;
-  static constexpr bool has_denorm_loss          = false;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  static constexpr bool has_infinity                                             = false;
+  static constexpr bool has_quiet_NaN                                            = false;
+  static constexpr bool has_signaling_NaN                                        = false;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_absent;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
     return type(0);
   }
@@ -264,15 +255,15 @@ public:
   static constexpr int digits10     = 0;
   static constexpr int max_digits10 = 0;
 
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
     return false;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
     return true;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return min();
   }
@@ -280,11 +271,11 @@ public:
   static constexpr bool is_integer = true;
   static constexpr bool is_exact   = true;
   static constexpr int radix       = 2;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  _CCCL_API static constexpr type epsilon() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return type(0);
   }
@@ -294,24 +285,24 @@ public:
   static constexpr int max_exponent   = 0;
   static constexpr int max_exponent10 = 0;
 
-  static constexpr bool has_infinity             = false;
-  static constexpr bool has_quiet_NaN            = false;
-  static constexpr bool has_signaling_NaN        = false;
-  static constexpr float_denorm_style has_denorm = denorm_absent;
-  static constexpr bool has_denorm_loss          = false;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  static constexpr bool has_infinity                                             = false;
+  static constexpr bool has_quiet_NaN                                            = false;
+  static constexpr bool has_signaling_NaN                                        = false;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_absent;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return type(0);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
     return type(0);
   }
@@ -334,81 +325,85 @@ public:
   static constexpr bool is_specialized = true;
 
   static constexpr bool is_signed   = true;
-  static constexpr int digits       = __FLT_MANT_DIG__;
-  static constexpr int digits10     = __FLT_DIG__;
+  static constexpr int digits       = FLT_MANT_DIG;
+  static constexpr int digits10     = FLT_DIG;
   static constexpr int max_digits10 = 2 + (digits * 30103l) / 100000l;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
-    return __FLT_MIN__;
+    return FLT_MIN;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
-    return __FLT_MAX__;
+    return FLT_MAX;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return -max();
   }
 
   static constexpr bool is_integer = false;
   static constexpr bool is_exact   = false;
-  static constexpr int radix       = __FLT_RADIX__;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  static constexpr int radix       = FLT_RADIX;
+  _CCCL_API static constexpr type epsilon() noexcept
   {
-    return __FLT_EPSILON__;
+    return FLT_EPSILON;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return 0.5F;
   }
 
-  static constexpr int min_exponent   = __FLT_MIN_EXP__;
-  static constexpr int min_exponent10 = __FLT_MIN_10_EXP__;
-  static constexpr int max_exponent   = __FLT_MAX_EXP__;
-  static constexpr int max_exponent10 = __FLT_MAX_10_EXP__;
+  static constexpr int min_exponent   = FLT_MIN_EXP;
+  static constexpr int min_exponent10 = FLT_MIN_10_EXP;
+  static constexpr int max_exponent   = FLT_MAX_EXP;
+  static constexpr int max_exponent10 = FLT_MAX_10_EXP;
 
-  static constexpr bool has_infinity             = true;
-  static constexpr bool has_quiet_NaN            = true;
-  static constexpr bool has_signaling_NaN        = true;
-  static constexpr float_denorm_style has_denorm = denorm_present;
-  static constexpr bool has_denorm_loss          = false;
+  static constexpr bool has_infinity                                             = true;
+  static constexpr bool has_quiet_NaN                                            = true;
+  static constexpr bool has_signaling_NaN                                        = true;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_present;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
 
 #if defined(_CCCL_BUILTIN_HUGE_VALF)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return _CCCL_BUILTIN_HUGE_VALF();
   }
 #else // ^^^ _CCCL_BUILTIN_HUGE_VALF ^^^ // vvv !_CCCL_BUILTIN_HUGE_VALF vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type infinity() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type infinity() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7f800000);
   }
 #endif // !_CCCL_BUILTIN_HUGE_VALF
 #if defined(_CCCL_BUILTIN_NANF)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return _CCCL_BUILTIN_NANF("");
   }
 #else // ^^^ _CCCL_BUILTIN_NANF ^^^ // vvv !_CCCL_BUILTIN_NANF vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type quiet_NaN() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type quiet_NaN() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7fc00000);
   }
 #endif // !_CCCL_BUILTIN_NANF
 #if defined(_CCCL_BUILTIN_NANSF)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return _CCCL_BUILTIN_NANSF("");
   }
 #else // ^^^ _CCCL_BUILTIN_NANSF ^^^ // vvv !_CCCL_BUILTIN_NANSF vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type signaling_NaN() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type signaling_NaN() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7fa00000);
   }
 #endif // !_CCCL_BUILTIN_NANSF
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
+#if defined(FLT_TRUE_MIN)
+    return FLT_TRUE_MIN;
+#else // ^^^ FLT_TRUE_MIN ^^^ // vvv !FLT_TRUE_MIN vvv
     return __FLT_DENORM_MIN__;
+#endif // ^^^ !FLT_TRUE_MIN ^^^
   }
 
   static constexpr bool is_iec559  = true;
@@ -429,81 +424,85 @@ public:
   static constexpr bool is_specialized = true;
 
   static constexpr bool is_signed   = true;
-  static constexpr int digits       = __DBL_MANT_DIG__;
-  static constexpr int digits10     = __DBL_DIG__;
+  static constexpr int digits       = DBL_MANT_DIG;
+  static constexpr int digits10     = DBL_DIG;
   static constexpr int max_digits10 = 2 + (digits * 30103l) / 100000l;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
-    return __DBL_MIN__;
+    return DBL_MIN;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
-    return __DBL_MAX__;
+    return DBL_MAX;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return -max();
   }
 
   static constexpr bool is_integer = false;
   static constexpr bool is_exact   = false;
-  static constexpr int radix       = __FLT_RADIX__;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  static constexpr int radix       = FLT_RADIX;
+  _CCCL_API static constexpr type epsilon() noexcept
   {
-    return __DBL_EPSILON__;
+    return DBL_EPSILON;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return 0.5;
   }
 
-  static constexpr int min_exponent   = __DBL_MIN_EXP__;
-  static constexpr int min_exponent10 = __DBL_MIN_10_EXP__;
-  static constexpr int max_exponent   = __DBL_MAX_EXP__;
-  static constexpr int max_exponent10 = __DBL_MAX_10_EXP__;
+  static constexpr int min_exponent   = DBL_MIN_EXP;
+  static constexpr int min_exponent10 = DBL_MIN_10_EXP;
+  static constexpr int max_exponent   = DBL_MAX_EXP;
+  static constexpr int max_exponent10 = DBL_MAX_10_EXP;
 
-  static constexpr bool has_infinity             = true;
-  static constexpr bool has_quiet_NaN            = true;
-  static constexpr bool has_signaling_NaN        = true;
-  static constexpr float_denorm_style has_denorm = denorm_present;
-  static constexpr bool has_denorm_loss          = false;
+  static constexpr bool has_infinity                                             = true;
+  static constexpr bool has_quiet_NaN                                            = true;
+  static constexpr bool has_signaling_NaN                                        = true;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_present;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
 
 #if defined(_CCCL_BUILTIN_HUGE_VAL)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return _CCCL_BUILTIN_HUGE_VAL();
   }
 #else // ^^^ _CCCL_BUILTIN_HUGE_VAL ^^^ // vvv !_CCCL_BUILTIN_HUGE_VAL vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type infinity() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type infinity() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7ff0000000000000);
   }
 #endif // !_CCCL_BUILTIN_HUGE_VAL
 #if defined(_CCCL_BUILTIN_NAN)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return _CCCL_BUILTIN_NAN("");
   }
 #else // ^^^ _CCCL_BUILTIN_NAN ^^^ // vvv !_CCCL_BUILTIN_NAN vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type quiet_NaN() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type quiet_NaN() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7ff8000000000000);
   }
 #endif // !_CCCL_BUILTIN_NAN
 #if defined(_CCCL_BUILTIN_NANS)
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return _CCCL_BUILTIN_NANS("");
   }
 #else // ^^^ _CCCL_BUILTIN_NANS ^^^ // vvv !_CCCL_BUILTIN_NANS vvv
-  _LIBCUDACXX_HIDE_FROM_ABI static _LIBCUDACXX_CONSTEXPR_BIT_CAST type signaling_NaN() noexcept
+  _CCCL_API inline static _LIBCUDACXX_CONSTEXPR_BIT_CAST type signaling_NaN() noexcept
   {
     return _CUDA_VSTD::bit_cast<type>(0x7ff4000000000000);
   }
 #endif // !_CCCL_BUILTIN_NANS
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
+#if defined(DBL_TRUE_MIN)
+    return DBL_TRUE_MIN;
+#else // ^^^ DBL_TRUE_MIN ^^^ // vvv !DBL_TRUE_MIN vvv
     return __DBL_DENORM_MIN__;
+#endif // ^^^ !DBL_TRUE_MIN ^^^
   }
 
   static constexpr bool is_iec559  = true;
@@ -526,59 +525,63 @@ public:
   static constexpr bool is_specialized = true;
 
   static constexpr bool is_signed   = true;
-  static constexpr int digits       = __LDBL_MANT_DIG__;
-  static constexpr int digits10     = __LDBL_DIG__;
+  static constexpr int digits       = LDBL_MANT_DIG;
+  static constexpr int digits10     = LDBL_DIG;
   static constexpr int max_digits10 = 2 + (digits * 30103l) / 100000l;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type min() noexcept
+  _CCCL_API static constexpr type min() noexcept
   {
-    return __LDBL_MIN__;
+    return LDBL_MIN;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type max() noexcept
+  _CCCL_API static constexpr type max() noexcept
   {
-    return __LDBL_MAX__;
+    return LDBL_MAX;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type lowest() noexcept
+  _CCCL_API static constexpr type lowest() noexcept
   {
     return -max();
   }
 
   static constexpr bool is_integer = false;
   static constexpr bool is_exact   = false;
-  static constexpr int radix       = __FLT_RADIX__;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type epsilon() noexcept
+  static constexpr int radix       = FLT_RADIX;
+  _CCCL_API static constexpr type epsilon() noexcept
   {
-    return __LDBL_EPSILON__;
+    return LDBL_EPSILON;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type round_error() noexcept
+  _CCCL_API static constexpr type round_error() noexcept
   {
     return 0.5L;
   }
 
-  static constexpr int min_exponent   = __LDBL_MIN_EXP__;
-  static constexpr int min_exponent10 = __LDBL_MIN_10_EXP__;
-  static constexpr int max_exponent   = __LDBL_MAX_EXP__;
-  static constexpr int max_exponent10 = __LDBL_MAX_10_EXP__;
+  static constexpr int min_exponent   = LDBL_MIN_EXP;
+  static constexpr int min_exponent10 = LDBL_MIN_10_EXP;
+  static constexpr int max_exponent   = LDBL_MAX_EXP;
+  static constexpr int max_exponent10 = LDBL_MAX_10_EXP;
 
-  static constexpr bool has_infinity             = true;
-  static constexpr bool has_quiet_NaN            = true;
-  static constexpr bool has_signaling_NaN        = true;
-  static constexpr float_denorm_style has_denorm = denorm_present;
-  static constexpr bool has_denorm_loss          = false;
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type infinity() noexcept
+  static constexpr bool has_infinity                                             = true;
+  static constexpr bool has_quiet_NaN                                            = true;
+  static constexpr bool has_signaling_NaN                                        = true;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr float_denorm_style has_denorm = denorm_present;
+  _LIBCUDACXX_DEPRECATED_IN_CXX23 static constexpr bool has_denorm_loss          = false;
+  _CCCL_API static constexpr type infinity() noexcept
   {
     return _CCCL_BUILTIN_HUGE_VALL();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type quiet_NaN() noexcept
+  _CCCL_API static constexpr type quiet_NaN() noexcept
   {
     return _CCCL_BUILTIN_NANL("");
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type signaling_NaN() noexcept
+  _CCCL_API static constexpr type signaling_NaN() noexcept
   {
     return _CCCL_BUILTIN_NANSL("");
   }
-  _LIBCUDACXX_HIDE_FROM_ABI static constexpr type denorm_min() noexcept
+  _CCCL_API static constexpr type denorm_min() noexcept
   {
+#  if defined(LDBL_TRUE_MIN)
+    return LDBL_TRUE_MIN;
+#  else // ^^^ LDBL_TRUE_MIN ^^^ // vvv !LDBL_TRUE_MIN vvv
     return __LDBL_DENORM_MIN__;
+#  endif // ^^^ !LDBL_TRUE_MIN ^^^
   }
 
   static constexpr bool is_iec559  = true;
@@ -609,4 +612,6 @@ class numeric_limits<const volatile _Tp> : public numeric_limits<_Tp>
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___LIMITS_NUMERIC_LIMITS_H
