@@ -45,7 +45,7 @@
 #include <cuda/std/limits>
 #include <cuda/std/span>
 
-_CCCL_PUSH_MACROS
+#include <cuda/std/__cccl/prologue.h>
 
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
@@ -59,19 +59,19 @@ namespace __mdspan_detail
 template <class _Tp, _Tp... _Values>
 struct __static_array
 {
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr size_t __size() noexcept
+  [[nodiscard]] _CCCL_API static constexpr size_t __size() noexcept
   {
     return sizeof...(_Values);
   }
 
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr _Tp __get(size_t __index) noexcept
+  [[nodiscard]] _CCCL_API static constexpr _Tp __get(size_t __index) noexcept
   {
     constexpr array<_Tp, sizeof...(_Values)> __array = {_Values...};
     return __array[__index];
   }
 
   template <size_t _Index>
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr _Tp __get()
+  [[nodiscard]] _CCCL_API static constexpr _Tp __get()
   {
     return __get(_Index);
   }
@@ -90,11 +90,11 @@ template <class _Tp, size_t _Size>
 struct __possibly_empty_array
 {
   _Tp __vals_[_Size];
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr _Tp& operator[](size_t __index)
+  [[nodiscard]] _CCCL_API constexpr _Tp& operator[](size_t __index)
   {
     return __vals_[__index];
   }
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr const _Tp& operator[](size_t __index) const
+  [[nodiscard]] _CCCL_API constexpr const _Tp& operator[](size_t __index) const
   {
     return __vals_[__index];
   }
@@ -104,29 +104,29 @@ template <class _Tp>
 struct __possibly_empty_array<_Tp, 0>
 {
 #if _CCCL_COMPILER(MSVC)
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr _Tp& operator[](size_t __index)
+  _CCCL_API constexpr _Tp& operator[](size_t __index)
   {
     return *__get(__index);
   }
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr const _Tp& operator[](size_t __index) const
+  _CCCL_API constexpr const _Tp& operator[](size_t __index) const
   {
     return *__get(__index);
   }
 
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr _Tp* __get(size_t)
+  _CCCL_API constexpr _Tp* __get(size_t)
   {
     return nullptr;
   }
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr const _Tp* __get(size_t) const
+  _CCCL_API constexpr const _Tp* __get(size_t) const
   {
     return nullptr;
   }
 #else // ^^^ _CCCL_COMPILER(MSVC) ^^^ / vvv !_CCCL_COMPILER(MSVC) vvv
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr _Tp& operator[](size_t)
+  _CCCL_API constexpr _Tp& operator[](size_t)
   {
     _CCCL_UNREACHABLE();
   }
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr const _Tp& operator[](size_t) const
+  _CCCL_API constexpr const _Tp& operator[](size_t) const
   {
     _CCCL_UNREACHABLE();
   }
@@ -142,8 +142,7 @@ struct __possibly_empty_array<_Tp, 0>
 template <size_t... _Values>
 struct __static_partial_sums
 {
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr array<size_t, sizeof...(_Values)>
-  __static_partial_sums_impl()
+  [[nodiscard]] _CCCL_API static constexpr array<size_t, sizeof...(_Values)> __static_partial_sums_impl()
   {
     array<size_t, sizeof...(_Values)> __values{_Values...};
     array<size_t, sizeof...(_Values)> __partial_sums{{}};
@@ -156,7 +155,7 @@ struct __static_partial_sums
     return __partial_sums;
   }
 
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr size_t __get(size_t __index)
+  [[nodiscard]] _CCCL_API static constexpr size_t __get(size_t __index)
   {
     constexpr array<size_t, sizeof...(_Values)> __result = __static_partial_sums_impl();
     return __result[__index];
@@ -176,8 +175,8 @@ constexpr size_t __count_dynamic_v = (size_t{0} + ... + static_cast<size_t>(_Val
 // The position of a dynamic value is indicated through a tag value.
 // We manually implement EBCO because MSVC and some odler compiler fail hard with [[no_unique_address]]
 template <class _TDynamic, class _TStatic, _TStatic _DynTag, _TStatic... _Values>
-struct __maybe_static_array
-    : private __possibly_empty_array<_TDynamic, __count_dynamic_v<_TStatic, _DynTag, _Values...>>
+struct _CCCL_DECLSPEC_EMPTY_BASES
+__maybe_static_array : private __possibly_empty_array<_TDynamic, __count_dynamic_v<_TStatic, _DynTag, _Values...>>
 {
   static_assert(_CCCL_TRAIT(is_convertible, _TStatic, _TDynamic),
                 "__maybe_static_array: _TStatic must be convertible to _TDynamic");
@@ -195,18 +194,18 @@ private:
   using _DynamicIdxMap = __static_partial_sums<static_cast<size_t>(_Values == _DynTag)...>;
 
   template <size_t... Indices>
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr _DynamicValues __zeros(index_sequence<Indices...>) noexcept
+  [[nodiscard]] _CCCL_API static constexpr _DynamicValues __zeros(index_sequence<Indices...>) noexcept
   {
     return _DynamicValues{((void) Indices, 0)...};
   }
 
 public:
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __maybe_static_array() noexcept
+  _CCCL_API constexpr __maybe_static_array() noexcept
       : _DynamicValues{__zeros(make_index_sequence<__size_dynamic_>())}
   {}
 
   template <class _Tp, size_t _Size>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __maybe_static_array(span<_Tp, _Size> __vals) noexcept
+  _CCCL_API constexpr __maybe_static_array(span<_Tp, _Size> __vals) noexcept
       : _DynamicValues{}
   {
     if constexpr (_Size == __size_dynamic_)
@@ -240,15 +239,15 @@ public:
 
   // constructors from dynamic values only -- this covers the case for rank() == 0
   _CCCL_TEMPLATE(class... _DynVals)
-  _CCCL_REQUIRES((sizeof...(_DynVals) == __size_dynamic_) && (!__all<__is_std_span<_DynVals>...>::value))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __maybe_static_array(_DynVals... __vals) noexcept
+  _CCCL_REQUIRES((sizeof...(_DynVals) == __size_dynamic_) && (!__all<__is_std_span_v<_DynVals>...>::value))
+  _CCCL_API constexpr __maybe_static_array(_DynVals... __vals) noexcept
       : _DynamicValues{static_cast<_TDynamic>(__vals)...}
   {}
 
   // constructors from all values -- here rank will be greater than 0
   _CCCL_TEMPLATE(class... _DynVals)
-  _CCCL_REQUIRES((sizeof...(_DynVals) != __size_dynamic_) && (!__all<__is_std_span<_DynVals>...>::value))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr __maybe_static_array(_DynVals... __vals)
+  _CCCL_REQUIRES((sizeof...(_DynVals) != __size_dynamic_) && (!__all<__is_std_span_v<_DynVals>...>::value))
+  _CCCL_API constexpr __maybe_static_array(_DynVals... __vals)
       : _DynamicValues{}
   {
     static_assert((sizeof...(_DynVals) == __size_), "Invalid number of values.");
@@ -273,7 +272,7 @@ public:
   }
 
   // access functions
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr _TStatic __static_value(size_t __i) noexcept
+  [[nodiscard]] _CCCL_API static constexpr _TStatic __static_value(size_t __i) noexcept
   {
     if constexpr (__size_ > 0)
     {
@@ -282,7 +281,7 @@ public:
     return _StaticValues::__get(__i);
   }
 
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr _TDynamic __value(size_t __i) const
+  [[nodiscard]] _CCCL_API constexpr _TDynamic __value(size_t __i) const
   {
     if constexpr (__size_ > 0)
     {
@@ -294,7 +293,7 @@ public:
            : static_cast<_TDynamic>(__static_val);
   }
 
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr _TDynamic operator[](size_t __i) const
+  [[nodiscard]] _CCCL_API constexpr _TDynamic operator[](size_t __i) const
   {
     if constexpr (__size_ > 0)
     {
@@ -304,11 +303,11 @@ public:
   }
 
   // observers
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr size_t __size()
+  [[nodiscard]] _CCCL_API static constexpr size_t __size()
   {
     return __size_;
   }
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr size_t __size_dynamic()
+  [[nodiscard]] _CCCL_API static constexpr size_t __size_dynamic()
   {
     return __size_dynamic_;
   }
@@ -324,9 +323,8 @@ static constexpr bool __potentially_narrowing =
 // if _From is not an integral, we just check positivity
 _CCCL_TEMPLATE(class _To, class _From)
 _CCCL_REQUIRES(integral<_To>)
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __is_representable_as(_From __value)
+[[nodiscard]] _CCCL_API constexpr bool __is_representable_as([[maybe_unused]] _From __value)
 {
-  (void) __value;
   if constexpr (integral<_From>)
   {
     if constexpr (_CCCL_TRAIT(is_signed, _From))
@@ -376,14 +374,14 @@ _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __is_representable_as(_
 
 _CCCL_TEMPLATE(class _To, class... _From)
 _CCCL_REQUIRES(integral<_To>)
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __are_representable_as(_From... __values)
+[[nodiscard]] _CCCL_API constexpr bool __are_representable_as(_From... __values)
 {
   return (__mdspan_detail::__is_representable_as<_To>(__values) && ... && true);
 }
 
 _CCCL_TEMPLATE(class _To, class _From, size_t _Size)
 _CCCL_REQUIRES(integral<_To>)
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __are_representable_as(span<_From, _Size> __values)
+[[nodiscard]] _CCCL_API constexpr bool __are_representable_as(span<_From, _Size> __values)
 {
   for (size_t __i = 0; __i != _Size; __i++)
   {
@@ -433,20 +431,20 @@ private:
 
 public:
   // [mdspan.extents.obs], observers of multidimensional index space
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr rank_type rank() noexcept
+  [[nodiscard]] _CCCL_API static constexpr rank_type rank() noexcept
   {
     return __rank_;
   }
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr rank_type rank_dynamic() noexcept
+  [[nodiscard]] _CCCL_API static constexpr rank_type rank_dynamic() noexcept
   {
     return __rank_dynamic_;
   }
 
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr index_type extent(rank_type __r) const noexcept
+  [[nodiscard]] _CCCL_API constexpr index_type extent(rank_type __r) const noexcept
   {
     return this->__value(__r);
   }
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI static constexpr size_t static_extent(rank_type __r) noexcept
+  [[nodiscard]] _CCCL_API static constexpr size_t static_extent(rank_type __r) noexcept
   {
     return _Values::__static_value(__r);
   }
@@ -459,7 +457,7 @@ public:
   _CCCL_TEMPLATE(class... _OtherIndexTypes)
   _CCCL_REQUIRES((sizeof...(_OtherIndexTypes) == __rank_ || sizeof...(_OtherIndexTypes) == __rank_dynamic_)
                    _CCCL_AND __mdspan_detail::__all_convertible_to_index_type<index_type, _OtherIndexTypes...>)
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr explicit extents(_OtherIndexTypes... __dynvals) noexcept
+  _CCCL_API constexpr explicit extents(_OtherIndexTypes... __dynvals) noexcept
       : _Values(static_cast<index_type>(__dynvals)...)
   {
     // Not catching this could lead to out of bounds errors later
@@ -475,20 +473,20 @@ public:
 
   _CCCL_TEMPLATE(class _OtherIndexType, size_t _Size)
   _CCCL_REQUIRES((_Size == __rank_dynamic_) _CCCL_AND __is_convertible_to_index_type<_OtherIndexType>)
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr extents(const array<_OtherIndexType, _Size>& __exts) noexcept
+  _CCCL_API constexpr extents(const array<_OtherIndexType, _Size>& __exts) noexcept
       : extents(span<const _OtherIndexType, _Size>(__exts))
   {}
 
   _CCCL_TEMPLATE(class _OtherIndexType, size_t _Size)
   _CCCL_REQUIRES((_Size == __rank_) _CCCL_AND(_Size != __rank_dynamic_)
                    _CCCL_AND __is_convertible_to_index_type<_OtherIndexType>)
-  _LIBCUDACXX_HIDE_FROM_ABI explicit constexpr extents(const array<_OtherIndexType, _Size>& __exts) noexcept
+  _CCCL_API explicit constexpr extents(const array<_OtherIndexType, _Size>& __exts) noexcept
       : extents(span<const _OtherIndexType, _Size>(__exts))
   {}
 
   _CCCL_TEMPLATE(class _OtherIndexType, size_t _Size)
   _CCCL_REQUIRES((_Size == __rank_dynamic_) _CCCL_AND __is_convertible_to_index_type<_OtherIndexType>)
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr extents(span<_OtherIndexType, _Size> __exts) noexcept
+  _CCCL_API constexpr extents(span<_OtherIndexType, _Size> __exts) noexcept
       : _Values(__exts)
   {
     // Not catching this could lead to out of bounds errors later
@@ -501,7 +499,7 @@ public:
   _CCCL_TEMPLATE(class _OtherIndexType, size_t _Size)
   _CCCL_REQUIRES((_Size != __rank_dynamic_) _CCCL_AND(_Size == __rank_)
                    _CCCL_AND __is_convertible_to_index_type<_OtherIndexType>)
-  _LIBCUDACXX_HIDE_FROM_ABI explicit constexpr extents(span<_OtherIndexType, _Size> __exts) noexcept
+  _CCCL_API explicit constexpr extents(span<_OtherIndexType, _Size> __exts) noexcept
       : _Values(__exts)
   {
     // Not catching this could lead to out of bounds errors later
@@ -514,15 +512,14 @@ public:
 private:
   // Function to construct extents storage from other extents.
   template <size_t _DynCount, size_t _Idx, class _OtherExtents, class... _DynamicValues>
-  _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr _Values __construct_vals_from_extents(
+  [[nodiscard]] _CCCL_API constexpr _Values __construct_vals_from_extents(
     integral_constant<size_t, _DynCount>,
     integral_constant<size_t, _Idx>,
-    const _OtherExtents& __exts,
+    [[maybe_unused]] const _OtherExtents& __exts,
     _DynamicValues... __dynamic_values) noexcept
   {
     if constexpr (_Idx == __rank_)
     {
-      (void) __exts;
       if constexpr (_DynCount == __rank_dynamic_)
       {
         return _Values{static_cast<index_type>(__dynamic_values)...};
@@ -553,8 +550,7 @@ private:
   }
 
   template <class _OtherIndexType, size_t... _OtherExtents>
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr extents(__extent_delegate_tag,
-                                              const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
+  _CCCL_API constexpr extents(__extent_delegate_tag, const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
       : _Values(__construct_vals_from_extents(integral_constant<size_t, 0>(), integral_constant<size_t, 0>(), __other))
   {
     if constexpr (rank() != 0)
@@ -594,7 +590,7 @@ public:
   _CCCL_TEMPLATE(class _OtherIndexType, size_t... _OtherExtents)
   _CCCL_REQUIRES((sizeof...(_OtherExtents) == sizeof...(_Extents)) _CCCL_AND __is_matching_extents<_OtherExtents...>
                    _CCCL_AND(!__is_explicit_conversion<_OtherIndexType, _OtherExtents...>))
-  _LIBCUDACXX_HIDE_FROM_ABI constexpr extents(const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
+  _CCCL_API constexpr extents(const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
       : extents(__extent_delegate_tag{}, __other)
   {}
 
@@ -602,14 +598,13 @@ public:
   _CCCL_REQUIRES((sizeof...(_OtherExtents) == sizeof...(_Extents))
                    _CCCL_AND __is_matching_extents<_OtherExtents...> _CCCL_AND
                      __is_explicit_conversion<_OtherIndexType, _OtherExtents...>)
-  _LIBCUDACXX_HIDE_FROM_ABI explicit constexpr extents(
-    const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
+  _CCCL_API explicit constexpr extents(const extents<_OtherIndexType, _OtherExtents...>& __other) noexcept
       : extents(__extent_delegate_tag{}, __other)
   {}
 
   // Comparison operator
   template <class _OtherIndexType, size_t... _OtherExtents>
-  _CCCL_NODISCARD_FRIEND _LIBCUDACXX_HIDE_FROM_ABI constexpr auto
+  [[nodiscard]] _CCCL_API friend constexpr bool
   operator==(const extents& __lhs, const extents<_OtherIndexType, _OtherExtents...>& __rhs) noexcept
   {
     if constexpr (rank() != sizeof...(_OtherExtents))
@@ -638,7 +633,7 @@ public:
 
 #if _CCCL_STD_VER <= 2017
   template <class _OtherIndexType, size_t... _OtherExtents>
-  _CCCL_NODISCARD_FRIEND _LIBCUDACXX_HIDE_FROM_ABI constexpr bool
+  [[nodiscard]] _CCCL_API friend constexpr bool
   operator!=(const extents& __lhs, const extents<_OtherIndexType, _OtherExtents...>& __rhs) noexcept
   {
     return !(__lhs == __rhs);
@@ -702,7 +697,7 @@ struct __is_extents<extents<_IndexType, _ExtentsPack...>> : true_type
 
 _CCCL_TEMPLATE(class _IndexType, class _From)
 _CCCL_REQUIRES(integral<_IndexType>)
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __is_index_in_extent(_IndexType __extent, _From __value)
+[[nodiscard]] _CCCL_API constexpr bool __is_index_in_extent(_IndexType __extent, _From __value)
 {
   if constexpr (integral<_From>)
   {
@@ -740,15 +735,14 @@ _CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool __is_index_in_extent(_I
 }
 
 template <size_t... _Idxs, class _Extents, class... _From>
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool
+[[nodiscard]] _CCCL_API constexpr bool
 __is_multidimensional_index_in_impl(index_sequence<_Idxs...>, const _Extents& __ext, _From... __values)
 {
   return (__mdspan_detail::__is_index_in_extent(__ext.extent(_Idxs), __values) && ... && true);
 }
 
 template <class _Extents, class... _From>
-_CCCL_NODISCARD _LIBCUDACXX_HIDE_FROM_ABI constexpr bool
-__is_multidimensional_index_in(const _Extents& __ext, _From... __values)
+[[nodiscard]] _CCCL_API constexpr bool __is_multidimensional_index_in(const _Extents& __ext, _From... __values)
 {
   return __mdspan_detail::__is_multidimensional_index_in_impl(
     make_index_sequence<_Extents::rank()>(), __ext, __values...);
@@ -758,6 +752,6 @@ __is_multidimensional_index_in(const _Extents& __ext, _From... __values)
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
-_CCCL_POP_MACROS
+#include <cuda/std/__cccl/epilogue.h>
 
 #endif // _LIBCUDACXX___MDSPAN_EXTENTS_H
