@@ -20,6 +20,8 @@
 #  pragma system_header
 #endif // no system header
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <class _Tp>
@@ -33,4 +35,6 @@ using type_identity_t _CCCL_NODEBUG_ALIAS = typename type_identity<_Tp>::type;
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___TYPE_TRAITS_TYPE_IDENTITY_H
