@@ -25,10 +25,13 @@
 #include <cuda/std/__utility/forward.h>
 #include <cuda/std/__utility/move.h>
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
+_CCCL_EXEC_CHECK_DISABLE
 template <class _T1, class _T2 = _T1>
-_LIBCUDACXX_HIDE_FROM_ABI constexpr _T1 exchange(_T1& __obj, _T2&& __new_value) noexcept(
+_CCCL_API constexpr _T1 exchange(_T1& __obj, _T2&& __new_value) noexcept(
   is_nothrow_move_constructible<_T1>::value && is_nothrow_assignable<_T1&, _T2>::value)
 {
   _T1 __old_value = _CUDA_VSTD::move(__obj);
@@ -38,4 +41,6 @@ _LIBCUDACXX_HIDE_FROM_ABI constexpr _T1 exchange(_T1& __obj, _T2&& __new_value)
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___UTILITY_EXCHANGE_H
