@@ -34,9 +34,12 @@
 #include <thrust/detail/type_traits.h>
 #include <thrust/type_traits/is_trivially_relocatable.h>
 
-#include <cmath>
-#include <complex>
-#include <sstream>
+#include <cuda/std/cmath>
+
+#if !_CCCL_COMPILER(NVRTC)
+#  include <complex>
+#  include <sstream>
+#endif // !_CCCL_COMPILER(NVRTC)
 
 #define THRUST_STD_COMPLEX_REAL(z) \
   reinterpret_cast<const typename ::cuda::std::remove_reference_t<decltype(z)>::value_type(&)[2]>(z)[0]
@@ -113,12 +116,13 @@ public:
   template <typename U>
   _CCCL_HOST_DEVICE complex(const complex<U>& z);
 
+#if !_CCCL_COMPILER(NVRTC)
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
    *
    *  \param z The \p complex to copy from.
    */
-  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<T>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const ::std::complex<T>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
@@ -128,7 +132,8 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<U>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const ::std::complex<U>& z);
+#endif // !_CCCL_COMPILER(NVRTC)
 
   /* --- Assignment Operators --- */
 
@@ -156,12 +161,13 @@ public:
   template <typename U>
   _CCCL_HOST_DEVICE complex& operator=(const complex<U>& z);
 
+#if !_CCCL_COMPILER(NVRTC)
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
    *
    *  \param z The \p complex to copy from.
    */
-  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<T>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const ::std::complex<T>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
@@ -171,7 +177,8 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<U>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const ::std::complex<U>& z);
+#endif // !_CCCL_COMPILER(NVRTC)
 
   /* --- Compound Assignment Operators --- */
 
@@ -329,14 +336,16 @@ public:
     data.y = im;
   }
 
+#if !_CCCL_COMPILER(NVRTC)
   /* --- Casting functions --- */
 
   /*! Casts this \p complex to a <tt>std::complex</tt> of the same type.
    */
-  _CCCL_HOST operator std::complex<T>() const
+  _CCCL_HOST operator ::std::complex<T>() const
   {
-    return std::complex<T>(real(), imag());
+    return ::std::complex<T>(real(), imag());
   }
+#endif // !_CCCL_COMPILER(NVRTC)
 
 private:
   struct alignas(sizeof(T) * 2) storage
@@ -499,7 +508,7 @@ _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator*(const T0
  *  type of the returned \p complex is the promoted type of the two arguments.
  *
  *  \param x The numerator (dividend).
- *  \param y The denomimator (divisor).
+ *  \param y The denominator (divisor).
  */
 template <typename T0, typename T1>
 _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator/(const complex<T0>& x, const complex<T1>& y);
@@ -510,7 +519,7 @@ _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator/(const co
  *  the type of the returned \p complex is the promoted type of the two arguments.
  *
  *  \param x The complex numerator (dividend).
- *  \param y The scalar denomimator (divisor).
+ *  \param y The scalar denominator (divisor).
  */
 template <typename T0, typename T1>
 _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator/(const complex<T0>& x, const T1& y);
@@ -521,7 +530,7 @@ _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator/(const co
  *  the type of the returned \p complex is the promoted type of the two arguments.
  *
  *  \param x The scalar numerator (dividend).
- *  \param y The complex denomimator (divisor).
+ *  \param y The complex denominator (divisor).
  */
 template <typename T0, typename T1>
 _CCCL_HOST_DEVICE complex<::cuda::std::common_type_t<T0, T1>> operator/(const T0& x, const complex<T1>& y);
@@ -718,6 +727,7 @@ _CCCL_HOST_DEVICE complex<T> asinh(const complex<T>& z);
 template <typename T>
 _CCCL_HOST_DEVICE complex<T> atanh(const complex<T>& z);
 
+#if !_CCCL_COMPILER(NVRTC)
 /* --- Stream Operators --- */
 
 /*! Writes to an output stream a \p complex number in the form (real, imaginary).
@@ -741,7 +751,8 @@ std::basic_ostream<CharT, Traits>& operator<<(std::basic_ostream<CharT, Traits>&
  *  \param z The \p complex number to set.
  */
 template <typename T, typename CharT, typename Traits>
-_CCCL_HOST std::basic_istream<CharT, Traits>& operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
+_CCCL_HOST ::std::basic_istream<CharT, Traits>& operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
+#endif // !_CCCL_COMPILER(NVRTC)
 
 /* --- Equality Operators --- */
 
@@ -753,13 +764,14 @@ _CCCL_HOST std::basic_istream<CharT, Traits>& operator>>(std::basic_istream<Char
 template <typename T0, typename T1>
 _CCCL_HOST_DEVICE bool operator==(const complex<T0>& x, const complex<T1>& y);
 
+#if !_CCCL_COMPILER(NVRTC)
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
  *  \param x The first \p complex.
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const complex<T0>& x, const std::complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const complex<T0>& x, const ::std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
@@ -767,7 +779,8 @@ _CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const complex<T0>& x, const
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const std::complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const ::std::complex<T0>& x, const complex<T1>& y);
+#endif // !_CCCL_COMPILER(NVRTC)
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
  *  the real part is equal to the scalar. Returns false otherwise.
@@ -795,13 +808,14 @@ _CCCL_HOST_DEVICE bool operator==(const complex<T0>& x, const T1& y);
 template <typename T0, typename T1>
 _CCCL_HOST_DEVICE bool operator!=(const complex<T0>& x, const complex<T1>& y);
 
+#if !_CCCL_COMPILER(NVRTC)
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
  *  \param x The first \p complex.
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const complex<T0>& x, const ::std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -809,7 +823,8 @@ _CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const complex<T0>& x, const
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const ::std::complex<T0>& x, const complex<T1>& y);
+#endif // !_CCCL_COMPILER(NVRTC)
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
  *  the real part is different from the scalar. Returns false otherwise.
