@@ -38,13 +38,24 @@
 #include <thrust/iterator/reverse_iterator.h>
 
 #include <cuda/std/__iterator/iterator_traits.h>
+#include <cuda/std/initializer_list>
 #include <cuda/std/utility>
 
-#include <initializer_list>
 #include <vector>
 
 THRUST_NAMESPACE_BEGIN
 
+struct default_init_t
+{};
+struct no_init_t
+{};
+
+//! Tag to indicate that a vector's elements should be default initialized
+inline constexpr default_init_t default_init;
+
+//! Tag to indicate that a vector's elements should not be initialized
+inline constexpr no_init_t no_init;
+
 namespace detail
 {
 
@@ -85,6 +96,16 @@ public:
    */
   explicit vector_base(size_type n);
 
+  //! This constructor creates a vector_base with default-initialized elements.
+  //! \param n The number of elements to create.
+  explicit vector_base(size_type n, default_init_t);
+
+  //! This constructor creates a vector_base without initializing elements. It mandates that the element type is
+  //! trivially default-constructible.
+  //! \param n The number of elements to create.
+  template <typename T2 = T>
+  explicit vector_base(size_type n, no_init_t);
+
   /*! This constructor creates a vector_base with value-initialized elements.
    *  \param n The number of elements to create.
    *  \param alloc The allocator to use by this vector_base.
@@ -140,18 +161,18 @@ public:
   /*! This constructor builds a \p vector_base from an intializer_list.
    *  \param il The intializer_list.
    */
-  vector_base(std::initializer_list<T> il);
+  vector_base(::cuda::std::initializer_list<T> il);
 
   /*! This constructor builds a \p vector_base from an intializer_list.
    *  \param il The intializer_list.
    *  \param alloc The allocator to use by this device_vector.
    */
-  vector_base(std::initializer_list<T> il, const Alloc& alloc);
+  vector_base(::cuda::std::initializer_list<T> il, const Alloc& alloc);
 
   /*! Assign operator copies from an initializer_list
    *  \param il The initializer_list.
    */
-  vector_base& operator=(std::initializer_list<T> il);
+  vector_base& operator=(::cuda::std::initializer_list<T> il);
 
   /*! Copy constructor copies from an exemplar vector_base with different
    *  type.
@@ -189,8 +210,7 @@ public:
    *  \param first The beginning of the range.
    *  \param last The end of the range.
    */
-  template <typename InputIterator,
-            ::cuda::std::enable_if_t<::cuda::std::__is_cpp17_input_iterator<InputIterator>::value, int> = 0>
+  template <typename InputIterator, ::cuda::std::enable_if_t<::cuda::std::__has_input_traversal<InputIterator>, int> = 0>
   vector_base(InputIterator first, InputIterator last);
 
   /*! This constructor builds a vector_base from a range.
@@ -198,8 +218,7 @@ public:
    *  \param last The end of the range.
    *  \param alloc The allocator to use by this vector_base.
    */
-  template <typename InputIterator,
-            ::cuda::std::enable_if_t<::cuda::std::__is_cpp17_input_iterator<InputIterator>::value, int> = 0>
+  template <typename InputIterator, ::cuda::std::enable_if_t<::cuda::std::__has_input_traversal<InputIterator>, int> = 0>
   vector_base(InputIterator first, InputIterator last, const Alloc& alloc);
 
   /*! The destructor erases the elements.
@@ -208,7 +227,7 @@ public:
 
   /*! \brief Resizes this vector_base to the specified number of elements.
    *  \param new_size Number of elements this vector_base should contain.
-   *  \throw std::length_error If n exceeds max_size9).
+   *  \throw std::length_error If n exceeds max_size().
    *
    *  This method will resize this vector_base to the specified number of
    *  elements. If the number is smaller than this vector_base's current
@@ -217,6 +236,19 @@ public:
    */
   void resize(size_type new_size);
 
+  //! \brief Resizes this vector_base to the specified number of elements, performing default-initialization instead of
+  //!         value-initialization.
+  //! \param new_size Number of elements this vector_base should contain.
+  //! \throw std::length_error If n exceeds max_size().
+  void resize(size_type new_size, default_init_t);
+
+  //! \brief Resizes this vector_base to the specified number of elements, without initializing elements. It mandates
+  //! that the element type is trivially default-constructible.
+  //! \param new_size Number of elements this vector_base should contain.
+  //! \throw std::length_error If n exceeds max_size().
+  template <typename T2 = T>
+  void resize(size_type new_size, no_init_t);
+
   /*! \brief Resizes this vector_base to the specified number of elements.
    *  \param new_size Number of elements this vector_base should contain.
    *  \param x Data with which new elements should be populated.
@@ -480,8 +512,8 @@ public:
    */
   allocator_type get_allocator() const;
 
-  _CCCL_SYNTHESIZE_SEQUENCE_ACCESS(vector_base, const_iterator);
-  _CCCL_SYNTHESIZE_SEQUENCE_REVERSE_ACCESS(vector_base, const_reverse_iterator);
+  _CCCL_SYNTHESIZE_SEQUENCE_ACCESS(vector_base, const_iterator)
+  _CCCL_SYNTHESIZE_SEQUENCE_REVERSE_ACCESS(vector_base, const_reverse_iterator)
 
 protected:
   // Our storage
@@ -491,13 +523,6 @@ protected:
   size_type m_size;
 
 private:
-  // these methods resolve the ambiguity of the constructor template of form (Iterator, Iterator)
-  template <typename IteratorOrIntegralType>
-  void init_dispatch(IteratorOrIntegralType begin, IteratorOrIntegralType end, false_type);
-
-  template <typename IteratorOrIntegralType>
-  void init_dispatch(IteratorOrIntegralType n, IteratorOrIntegralType value, true_type);
-
   template <typename InputIterator>
   void range_init(InputIterator first, InputIterator last);
 
@@ -515,6 +540,7 @@ private:
   void insert_dispatch(iterator position, InputIteratorOrIntegralType n, InputIteratorOrIntegralType x, true_type);
 
   // this method appends n value-initialized elements at the end
+  template <bool SkipInit = false>
   void append(size_type n);
 
   // this method performs insertion from a fill value
@@ -524,14 +550,6 @@ private:
   template <typename InputIterator>
   void copy_insert(iterator position, InputIterator first, InputIterator last);
 
-  // these methods resolve the ambiguity of the assign() template of form (InputIterator, InputIterator)
-  template <typename InputIterator>
-  void assign_dispatch(InputIterator first, InputIterator last, false_type);
-
-  // these methods resolve the ambiguity of the assign() template of form (InputIterator, InputIterator)
-  template <typename Integral>
-  void assign_dispatch(Integral n, Integral x, true_type);
-
   // this method performs assignment from a range
   template <typename InputIterator>
   void range_assign(InputIterator first, InputIterator last);
