@@ -235,7 +235,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin_s16x2_relu(const unsi
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimax3_s32(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "max.s32 t1, %1, %2; \n\t"
@@ -250,8 +250,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimax3_s32(const int a, const int b,
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_s16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
-  // Future asm code (naming/syntax may change):
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "max.s16x2 t1, %1, %2; \n\t"
       "max.s16x2 %0, t1, %3;}\n\t"
@@ -291,8 +290,8 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_s16x2(const unsigned
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_u32(const unsigned int a, const unsigned int b, const unsigned int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
-int res;
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
+  int res;
   asm ("{.reg .u32 t1; \n\t"
       "max.u32 t1, %1, %2; \n\t"
       "max.u32 %0, t1, %3;}\n\t"
@@ -306,7 +305,7 @@ int res;
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_u16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "max.u16x2 t1, %1, %2; \n\t"
       "max.u16x2 %0, t1, %3;}\n\t"
@@ -337,7 +336,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_u16x2(const unsigned
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimin3_s32(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "min.s32 t1, %1, %2; \n\t"
@@ -352,7 +351,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimin3_s32(const int a, const int b,
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_s16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "min.s16x2 t1, %1, %2; \n\t"
       "min.s16x2 %0, t1, %3;}\n\t"
@@ -393,7 +392,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_s16x2(const unsigned
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_u32(const unsigned int a, const unsigned int b, const unsigned int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .u32 t1; \n\t"
       "min.u32 t1, %1, %2; \n\t"
@@ -408,7 +407,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_u32(const unsigned i
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_u16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "min.u16x2 t1, %1, %2; \n\t"
       "min.u16x2 %0, t1, %3;}\n\t"
@@ -439,7 +438,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_u16x2(const unsigned
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimax3_s32_relu(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "max.s32.relu t1, %1, %2; \n\t"
@@ -456,7 +455,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimax3_s32_relu(const int a, const i
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_s16x2_relu(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "max.s16x2.relu t1, %1, %2; \n\t"
       "max.s16x2.relu %0, t1, %3;}\n\t"
@@ -497,7 +496,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimax3_s16x2_relu(const uns
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimin3_s32_relu(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "min.s32.relu t1, %1, %2; \n\t"
@@ -514,7 +513,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __vimin3_s32_relu(const int a, const i
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_s16x2_relu(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "min.s16x2.relu t1, %1, %2; \n\t"
       "min.s16x2.relu %0, t1, %3;}\n\t"
@@ -556,7 +555,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __vimin3_s16x2_relu(const uns
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmax_s32(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "add.s32 t1, %1, %2; \n\t"
@@ -571,7 +570,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmax_s32(const int a, const int
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_s16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.s16x2 t1, %1, %2; \n\t"
       "max.s16x2 %0, t1, %3;}\n\t"
@@ -612,7 +611,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_s16x2(const unsign
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_u32(const unsigned int a, const unsigned int b, const unsigned int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   unsigned int res;
   asm ("{.reg .u32 t1; \n\t"
       "add.u32 t1, %1, %2; \n\t"
@@ -627,7 +626,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_u32(const unsigned
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_u16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.u16x2 t1, %1, %2; \n\t"
       "max.u16x2 %0, t1, %3;}\n\t"
@@ -658,7 +657,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_u16x2(const unsign
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmin_s32(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "add.s32 t1, %1, %2; \n\t"
@@ -673,7 +672,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmin_s32(const int a, const int
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_s16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.s16x2 t1, %1, %2; \n\t"
       "min.s16x2 %0, t1, %3;}\n\t"
@@ -714,7 +713,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_s16x2(const unsign
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_u32(const unsigned int a, const unsigned int b, const unsigned int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   unsigned int res;
   asm ("{.reg .u32 t1; \n\t"
       "add.u32 t1, %1, %2; \n\t"
@@ -729,7 +728,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_u32(const unsigned
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_u16x2(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.u16x2 t1, %1, %2; \n\t"
       "min.u16x2 %0, t1, %3;}\n\t"
@@ -760,7 +759,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_u16x2(const unsign
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmax_s32_relu(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "add.s32 t1, %1, %2; \n\t"
@@ -777,7 +776,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmax_s32_relu(const int a, const
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_s16x2_relu(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.s16x2 t1, %1, %2; \n\t"
       "max.s16x2.relu %0, t1, %3;}\n\t"
@@ -818,7 +817,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmax_s16x2_relu(const u
 }
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmin_s32_relu(const int a, const int b, const int c){
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   int res;
   asm ("{.reg .s32 t1; \n\t"
       "add.s32 t1, %1, %2; \n\t"
@@ -835,7 +834,7 @@ __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ int __viaddmin_s32_relu(const int a, const
 
 __DEVICE_HOST_FUNCTIONS_STATIC_DECL__ unsigned int __viaddmin_s16x2_relu(const unsigned int a, const unsigned int b, const unsigned int c){
   unsigned int res;
-#ifdef __CUDA_AND_AT_LEAST_SM_90__
+#if (defined(__CUDA_AND_AT_LEAST_SM_90__) && (__CUDA_ARCH__ != 1100))
   asm ("{.reg .b32 t1; \n\t"
       "add.s16x2 t1, %1, %2; \n\t"
       "min.s16x2.relu %0, t1, %3;}\n\t"
