@@ -1,5 +1,5 @@
 /*
- * Copyright 2024 NVIDIA Corporation.  All rights reserved.
+ * Copyright 2024-2025 NVIDIA Corporation.  All rights reserved.
  *
  * NOTICE TO LICENSEE:
  *
@@ -295,9 +295,29 @@ __nv_cvt_halfraw_to_fp6(const __half_raw x,
                         const __nv_fp6_interpretation_t fp6_interpretation,
                         const enum cudaRoundMode rounding) {
     assert((rounding == cudaRoundNearest) || (rounding == cudaRoundZero));
+
     __nv_fp6_storage_t res = 0U;
-    float fx = __internal_halfraw_to_float(x);
-    res = __nv_cvt_float_to_fp6(fx, fp6_interpretation, rounding);
+#if (__CUDA_FP8_INTERNAL_CAN_RELY_ON_PTX_FOR_SHORTTYPESCVT__)
+    if (rounding == cudaRoundNearest) {
+        unsigned int half2_storage = (unsigned int)(x.x);
+        __nv_fp6x2_storage_t tmp;
+        if (fp6_interpretation == __NV_E3M2) {
+            asm("{cvt.rn.satfinite.e3m2x2.f16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(half2_storage));
+        } else {
+            asm("{cvt.rn.satfinite.e2m3x2.f16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(half2_storage));
+        }
+        res = (__nv_fp6_storage_t)tmp;
+    } else
+#endif
+    {
+        float fx = __internal_halfraw_to_float(x);
+        res = __nv_cvt_float_to_fp6(fx, fp6_interpretation, rounding);
+    }
+
     return res;
 }
 
@@ -307,16 +327,35 @@ __CUDA_HOSTDEVICE_FP6_DECL__ __nv_fp6x2_storage_t __nv_cvt_halfraw2_to_fp6x2(
     const enum cudaRoundMode rounding) {
     assert((rounding == cudaRoundNearest) || (rounding == cudaRoundZero));
     __nv_fp6x2_storage_t tmp;
-    __half_raw raw;
-    raw.x = x.x;
-    __nv_fp6_storage_t lo =
-        __nv_cvt_halfraw_to_fp6(raw, fp6_interpretation, rounding);
-    raw.x = x.y;
-    __nv_fp6_storage_t hi =
-        __nv_cvt_halfraw_to_fp6(raw, fp6_interpretation, rounding);
-    tmp = hi;
-    tmp = (__nv_fp6x2_storage_t)(tmp << 8U);
-    tmp = (__nv_fp6x2_storage_t)(tmp | lo);
+
+#if (__CUDA_FP8_INTERNAL_CAN_RELY_ON_PTX_FOR_SHORTTYPESCVT__)
+    if (rounding == cudaRoundNearest) {
+        unsigned int half2_storage;
+        (void)memcpy(&half2_storage, &x, sizeof(x));
+
+        if (fp6_interpretation == __NV_E3M2) {
+            asm("{cvt.rn.satfinite.e3m2x2.f16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(half2_storage));
+        } else {
+            asm("{cvt.rn.satfinite.e2m3x2.f16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(half2_storage));
+        }
+    } else
+#endif
+    {
+        __half_raw raw;
+        raw.x = x.x;
+        __nv_fp6_storage_t lo =
+            __nv_cvt_halfraw_to_fp6(raw, fp6_interpretation, rounding);
+        raw.x = x.y;
+        __nv_fp6_storage_t hi =
+            __nv_cvt_halfraw_to_fp6(raw, fp6_interpretation, rounding);
+        tmp = hi;
+        tmp = (__nv_fp6x2_storage_t)(tmp << 8U);
+        tmp = (__nv_fp6x2_storage_t)(tmp | lo);
+    }
     return tmp;
 }
 
@@ -324,9 +363,29 @@ __CUDA_HOSTDEVICE_FP6_DECL__ __nv_fp6_storage_t __nv_cvt_bfloat16raw_to_fp6(
     const __nv_bfloat16_raw x,
     const __nv_fp6_interpretation_t fp6_interpretation,
     const enum cudaRoundMode rounding) {
-    const float fx = __internal_bf16raw_to_float(x);
-    const __nv_fp6_storage_t res =
-        __nv_cvt_float_to_fp6(fx, fp6_interpretation, rounding);
+
+    __nv_fp6_storage_t res = 0U;
+#if (__CUDA_FP8_INTERNAL_CAN_RELY_ON_PTX_FOR_SHORTTYPESCVT__)
+    if (rounding == cudaRoundNearest) {
+        unsigned int bf162_storage = (unsigned int)(x.x);
+        __nv_fp6x2_storage_t tmp;
+        if (fp6_interpretation == __NV_E3M2) {
+            asm("{cvt.rn.satfinite.e3m2x2.bf16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(bf162_storage));
+        } else {
+            asm("{cvt.rn.satfinite.e2m3x2.bf16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(bf162_storage));
+        }
+        res = (__nv_fp6_storage_t)tmp;
+    } else
+#endif
+    {
+        float fx = __internal_bf16raw_to_float(x);
+        res = __nv_cvt_float_to_fp6(fx, fp6_interpretation, rounding);
+    }
+
     return res;
 }
 
@@ -335,17 +394,38 @@ __nv_cvt_bfloat16raw2_to_fp6x2(
     const __nv_bfloat162_raw x,
     const __nv_fp6_interpretation_t fp6_interpretation,
     const enum cudaRoundMode rounding) {
-    __nv_bfloat16_raw raw;
-    raw.x = x.y;
-    __nv_fp6x2_storage_t storage =
-        (__nv_fp6x2_storage_t)__nv_cvt_bfloat16raw_to_fp6(raw,
-                                        fp6_interpretation, rounding);
-    storage = (__nv_fp6x2_storage_t)(storage << 8U);
-    raw.x = x.x;
-    storage = (__nv_fp6x2_storage_t)(storage |
-                                     __nv_cvt_bfloat16raw_to_fp6(raw,
-                                        fp6_interpretation, rounding));
-    return storage;
+
+    __nv_fp6x2_storage_t tmp;
+
+#if (__CUDA_FP8_INTERNAL_CAN_RELY_ON_PTX_FOR_SHORTTYPESCVT__)
+    if (rounding == cudaRoundNearest) {
+        unsigned int bf162_storage;
+        (void)memcpy(&bf162_storage, &x, sizeof(x));
+
+        if (fp6_interpretation == __NV_E3M2) {
+            asm("{cvt.rn.satfinite.e3m2x2.bf16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(bf162_storage));
+        } else {
+            asm("{cvt.rn.satfinite.e2m3x2.bf16x2 %0, %1;}\n"
+                : "=h"(tmp)
+                : "r"(bf162_storage));
+        }
+    } else
+#endif
+    {
+        __nv_bfloat16_raw raw;
+        raw.x = x.y;
+        tmp =
+            (__nv_fp6x2_storage_t)__nv_cvt_bfloat16raw_to_fp6(raw,
+                                            fp6_interpretation, rounding);
+        tmp = (__nv_fp6x2_storage_t)(tmp << 8U);
+        raw.x = x.x;
+        tmp = (__nv_fp6x2_storage_t)(tmp |
+                                        __nv_cvt_bfloat16raw_to_fp6(raw,
+                                            fp6_interpretation, rounding));
+    }
+    return tmp;
 }
 
 __CUDA_HOSTDEVICE_FP6_DECL__ __half2_raw
