@@ -793,7 +793,7 @@ typedef enum CUpti_driver_api_trace_cbid_enum {
     CUPTI_DRIVER_TRACE_CBID_cuEventElapsedTime_v2                                          = 780,
     CUPTI_DRIVER_TRACE_CBID_cuTensorMapEncodeIm2colWide                                    = 781,
     CUPTI_DRIVER_TRACE_CBID_cuGreenCtxGetId                                                = 782,
-    CUPTI_DRIVER_TRACE_CBID_cuStreamCreateForCaptureToCig                                  = 783,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamBeginCaptureToCig                                      = 783,
     CUPTI_DRIVER_TRACE_CBID_cuMemPrefetchBatchAsync                                        = 784,
     CUPTI_DRIVER_TRACE_CBID_cuMemPrefetchBatchAsync_ptsz                                   = 785,
     CUPTI_DRIVER_TRACE_CBID_cuSemaphoreCreate                                              = 786,
@@ -817,7 +817,23 @@ typedef enum CUpti_driver_api_trace_cbid_enum {
     CUPTI_DRIVER_TRACE_CBID_cuDeviceGetP2PAtomicCapabilities                               = 804,
     CUPTI_DRIVER_TRACE_CBID_cuDeviceGetHostAtomicCapabilities                              = 805,
     CUPTI_DRIVER_TRACE_CBID_cuDriverGetGpuCodeIsaVersion                                   = 806,
-    CUPTI_DRIVER_TRACE_CBID_SIZE                                                           = 807,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamGetDevResource                                         = 807,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamGetDevResource_ptsz                                    = 808,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphNodeGetContainingGraph                                  = 809,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphNodeGetLocalId                                          = 810,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphNodeGetToolsId                                          = 811,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphGetId                                                   = 812,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphExecGetId                                               = 813,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamBeginCaptureToCig_ptsz                                 = 814,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamEndCaptureToCig                                        = 815,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamEndCaptureToCig_ptsz                                   = 816,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphCreateWithArguments                                     = 817,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphNodeAddRelocation                                       = 818,
+    CUPTI_DRIVER_TRACE_CBID_cuGraphLaunchWithArguments                                     = 819,
+    CUPTI_DRIVER_TRACE_CBID_cuMulticastBindMem_v2                                          = 820,
+    CUPTI_DRIVER_TRACE_CBID_cuMulticastBindAddr_v2                                         = 821,
+    CUPTI_DRIVER_TRACE_CBID_cuDevSmResourceSplit                                           = 822,
+    CUPTI_DRIVER_TRACE_CBID_SIZE                                                           = 823,
     CUPTI_DRIVER_TRACE_CBID_FORCE_INT                                                      = 0x7fffffff
 } CUpti_driver_api_trace_cbid;
 
