@@ -555,6 +555,7 @@ typedef struct CUpti_Profiler_GetCounterAvailability_Params
                                                         //!< `counterAvailabilityImageSize`, otherwise `counterAvailabilityImageSize` should be set to the size of
                                                         //!< `pCounterAvailabilityImage`, and on return it would be overwritten with number of actual bytes copied
     uint8_t* pCounterAvailabilityImage;                 //!< [in] buffer receiving counter availability image, may be NULL
+    bool bAllowDeviceLevelCounters;                      //!< [in] if true, device level counters are included in the counter availability image
 } CUpti_Profiler_GetCounterAvailability_Params;
 #define CUpti_Profiler_GetCounterAvailability_Params_STRUCT_SIZE                  CUPTI_PROFILER_STRUCT_SIZE(CUpti_Profiler_GetCounterAvailability_Params, pCounterAvailabilityImage)
 
@@ -605,8 +606,9 @@ typedef struct
     CUpti_Profiler_Support_Level cmp;                 //!< [out] SUPPORTED if not NVIDIA Crypto Mining Processors (CMP), UNSUPPORTED otherwise
     CUpti_Profiler_Support_Level wsl;                 //!< [out] SUPPORTED if WSL supported, UNSUPPORTED otherwise
     CUpti_Profiler_API     api;                       //!< [in] the CUPTI API type for which device support will be checked
+    CUpti_Profiler_Support_Level sku;                 //!< [out] SUPPORTED if SKU supported, UNSUPPORTED otherwise
 } CUpti_Profiler_DeviceSupported_Params;
-#define CUpti_Profiler_DeviceSupported_Params_STRUCT_SIZE CUPTI_PROFILER_STRUCT_SIZE(CUpti_Profiler_DeviceSupported_Params, api)
+#define CUpti_Profiler_DeviceSupported_Params_STRUCT_SIZE CUPTI_PROFILER_STRUCT_SIZE(CUpti_Profiler_DeviceSupported_Params, sku)
 
 /**
  * \brief Query device compatibility with Profiling API
