@@ -145,14 +145,14 @@ typedef enum
  */
 typedef enum
 {
+    NV_FILE_FLAG_NONE            =  0,
     NV_FILE_FLAG_HINT            = (1 << 0),                         //!< Default no hint
     NV_FILE_FLAG_MASKOUT         = (1 << 1),                         //!< For /proc/driver/nvidia/gpus
     NV_FILE_FLAG_CONTENT         = (1 << 2),                         //!< For /proc/driver/nvidia/params
                                                                      //!< For SYMLINK
                                                                      //!< Use \p nvSandboxUtilsGetFileContent to get name of the linked file
-    NV_FILE_FLAG_DEPRECTATED     = (1 << 3),                         //!< For all the FIRMWARE GSP file
+    NV_FILE_FLAG_DEPRECATED      = (1 << 3),                         //!< For all the FIRMWARE GSP file
     NV_FILE_FLAG_CANDIDATES      = (1 << 4),                         //!< For libcuda.so
-    NV_FILE_FLAG_NONE            =  0,
 } nvSandboxUtilsFileFlag_t;
 
 /**
@@ -168,51 +168,62 @@ typedef enum
 
 typedef enum
 {
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_LIB                     = 0,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_BINARY                  = 1,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_DATA                    = 2,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_ICD                     = 3,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_PROFILE                 = 4,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_JSON                    = 5,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_FIRMWARE                = 6,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_MODPROBE                = 7,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_SYMLINK                 = 8,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_XMODULE_SHARED_LIB      = 9,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_GLX_MODULE_SHARED_LIB   = 10,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_LIB                         = 0,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_BINARY                      = 1,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_DATA                        = 2,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_ICD                         = 3,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_PROFILE                     = 4,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_JSON                        = 5,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_FIRMWARE                    = 6,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_MODPROBE                    = 7,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_SYMLINK                     = 8,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_XMODULE_SHARED_LIB          = 9,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_GLX_MODULE_SHARED_LIB       = 10,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_IPC                         = 11,
     NVSANDBOXUTILS_NUM_DRIVER_FILE_TYPE,
-    NVSANDBOXUTILS_DRIVER_FILE_TYPE_INVALID                 = 0xFFFF,
+    NVSANDBOXUTILS_DRIVER_FILE_TYPE_INVALID                     = 0xFFFF,
 } nvSandboxUtilsDriverFileType_t;
 
 typedef enum
 {
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_FIRMWARE            = 0,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_MODPROBE            = 1,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVPD                = 2,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_UTILS               = 3,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVML                = 4,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVAPI               = 5,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_CUDA                = 6,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_OPENCL              = 7,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_OPTIX               = 8,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VIDEO               = 9,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL                 = 10,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_HEADLESS        = 11,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_GBM             = 12,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_WAYLAND         = 13,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_X11             = 14,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_GLX                 = 15,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_GBM                 = 16,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VULKAN              = 17,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_POWERD              = 18,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_XDRIVER             = 19,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NGX                 = 20,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VGPU                = 21,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVSANDBOXUTILS      = 22,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVPRESENT           = 23,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_FIRMWARE                = 0,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_MODPROBE                = 1,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVPD                    = 2,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_UTILS                   = 3,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVML                    = 4,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVAPI                   = 5,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_CUDA                    = 6,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_OPENCL                  = 7,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_OPTIX                   = 8,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VIDEO                   = 9,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL                     = 10,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_HEADLESS            = 11,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_GBM                 = 12,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_WAYLAND             = 13,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_EGL_X11                 = 14,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_GLX                     = 15,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_GBM                     = 16,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VULKAN                  = 17,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_POWERD                  = 18,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_XDRIVER                 = 19,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NGX                     = 20,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_VGPU                    = 21,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVSANDBOXUTILS          = 22,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_NVPRESENT               = 23,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_IPC                     = 24,
     NVSANDBOXUTILS_NUM_DRIVER_FILE_CATEGORY,
-    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_INVALID             = 0xFFFF,
+    NVSANDBOXUTILS_DRIVER_FILE_CATEGORY_INVALID                 = 0xFFFF,
 } nvSandboxUtilsDriverFileCategory_t;
 
+typedef enum
+{
+    NVSANDBOXUTILS_DRIVER_FILE_SUBTYPE_IPC_SOCKET_MPS_PIPE      = 0,
+    NVSANDBOXUTILS_DRIVER_FILE_SUBTYPE_IPC_SOCKET_FM            = 1,
+    NVSANDBOXUTILS_DRIVER_FILE_SUBTYPE_IPC_SOCKET_PERSISTENCED  = 2,
+    NVSANDBOXUTILS_NUM_DRIVER_FILE_SUBTYPE                      = 3,
+    NVSANDBOXUTILS_DRIVER_FILE_SUBTYPE_INVALID                  = 0xFFFF,
+} nvSandboxUtilsDriverFileSubtype_t;
+
 /** @} */
 
 /***************************************************************************************************/
@@ -289,6 +300,7 @@ typedef struct nvSandboxUtilsDriverFile_v1_t
 {
     struct nvSandboxUtilsDriverFile_v1_t *next;
     nvSandboxUtilsDriverFileType_t type;
+    nvSandboxUtilsDriverFileSubtype_t subtype;
     nvSandboxUtilsMask255_t categories;                              //<! Bit mask that can hold multiple categories
     nvSandboxUtilsMask255_t flags;                                   //<! Bit mask that can hold multiple flags
     char *filePath;                                                  //<! Absolute file path
