@@ -113,27 +113,29 @@
 # define __NV_SILENCE_DEPRECATION_BEGIN
 # define __NV_SILENCE_DEPRECATION_END
 #elif defined(__CUDACC__) && defined(_MSC_VER)
-# define __NV_SILENCE_DEPRECATION_BEGIN \
-  __NV_SILENCE_HOST_DEPRECATION_BEGIN \
+# define __NV_SILENCE_DEPRECATION_BEGIN                                       \
   __pragma(nv_diagnostic push)                                                \
-  __pragma(nv_diag_suppress 1444)
-# define __NV_SILENCE_DEPRECATION_END \
-  __NV_SILENCE_HOST_DEPRECATION_END \
+  __pragma(nv_diag_suppress 20199)                                            \
+  __pragma(nv_diag_suppress 1444)                                             \
+  __NV_SILENCE_HOST_DEPRECATION_BEGIN
+# define __NV_SILENCE_DEPRECATION_END                                         \
+  __NV_SILENCE_HOST_DEPRECATION_END                                           \
   __pragma(nv_diagnostic pop)
 #elif defined(__CUDACC__)
-# define __NV_SILENCE_DEPRECATION_BEGIN \
+# define __NV_SILENCE_DEPRECATION_BEGIN                                       \
   _Pragma("nv_diagnostic push")                                               \
   _Pragma("nv_diag_suppress 20199")                                           \
   _Pragma("nv_diag_suppress 1444")                                            \
   __NV_SILENCE_HOST_DEPRECATION_BEGIN 
-# define __NV_SILENCE_DEPRECATION_END \
-  __NV_SILENCE_HOST_DEPRECATION_END \
+# define __NV_SILENCE_DEPRECATION_END                                         \
+  __NV_SILENCE_HOST_DEPRECATION_END                                           \
   _Pragma("nv_diagnostic pop")
 #else
 #define __NV_SILENCE_DEPRECATION_BEGIN __NV_SILENCE_HOST_DEPRECATION_BEGIN
 #define __NV_SILENCE_DEPRECATION_END __NV_SILENCE_HOST_DEPRECATION_END
 #endif
 
+
 #if defined(__NV_NO_VECTOR_DEPRECATION_DIAG)
 # define __VECTOR_TYPE_DEPRECATED__(msg)
 #elif defined(_WIN32)
