@@ -1280,7 +1280,7 @@ static int nvfs_pin_gpu_pages(nvfs_ioctl_map_t *input_param,
         }
 
         if(gpu_buf_len < GPU_PAGE_SIZE &&
-		(input_param->sbuf_block * NVFS_BLOCK_SIZE) <
+		(input_param->sbuf_block * (unsigned long long)NVFS_BLOCK_SIZE) <
 		(gpuvaddr - gpu_virt_start + gpu_buf_len))
         {
 		nvfs_err("invalid shadow buf size provided %u, gpu_buf_len: %lld, gpuvaddr: %llx \n",
@@ -1511,7 +1511,7 @@ static int nvfs_map(nvfs_ioctl_map_t *input_param)
 	nvfs_get_ops();
 
         nvfs_mgroup = nvfs_mgroup_pin_shadow_pages(input_param->cpuvaddr,
-				input_param->sbuf_block * NVFS_BLOCK_SIZE);
+				input_param->sbuf_block * (unsigned long long)NVFS_BLOCK_SIZE);
 	if (!nvfs_mgroup) {
 		nvfs_err("%s:%d Error nvfs_setup_shadow_buffer\n",
 				__func__, __LINE__);
@@ -2469,7 +2469,7 @@ static int get_nvidia_driver_version(void){
 	char buf[NVIDIA_DRIVER_BUF_SIZE];
 	loff_t pos = 0;
 	ssize_t bytes_read;
-	int value;
+	int value = -1;
 
 	file = filp_open(NVIDIA_DRIVER_PATH, O_RDONLY, 0);
 	if (IS_ERR(file)) {
